*===============================================================;
*  Title:  PROGRAM A1 ASSIGNS AHRQ PREVENTION QUALITY INDICATORS
*          TO INPATIENT RECORDS
*
*  Description:;
*         ASSIGNS THE OUTCOME OF INTEREST FLAGS TO INPATIENT
*         RECORDS;
*
*          >>>  VERSION 4.1, December 2009 <<<
*
*  USER NOTE:  Make sure you have created format library 
*              (using PQFMTS.SAS) BEFORE running this program.
*
*===============================================================;
FILENAME CONTROL 'C:\PATHNAME\CONTROL_PQI.SAS'; *<===USER MUST modify;

%INCLUDE CONTROL;


 TITLE2 'PROGRAM A1';
 TITLE3 'AHRQ PREVENTION QUALITY INDICATORS: ASSIGN QIS TO INPATIENT DATA';

 * -------------------------------------------------------------- ;
 * --- PREVENTION QUALITY INDICATOR (PQI) NAMING CONVENTION:  --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PREVENTION QUALITY     --- ;
 * --- INDICATOR AS ONE OF THE FOLLOWING:
                (O) OBSERVED RATES
                (E) EXPECTED RATES
                (R) RISK-ADJUSTED RATES
                (S) SMOOTHED RATES
                (T) NUMERATOR ("TOP")
                (P) POPULATION ("POP")
 * --- THE SECOND LETTER REFERS TO THE INDICATOR              --- ;
 * --- SUBTYPE, (A)MBULATORY CARE SENSITIVE CONDITION. THE    --- ;
 * --- NEXT TWO CHARACTERS ARE ALWAYS 'PQ'. THE LAST TWO      --- ;
 * --- DIGITS ARE THE INDICATOR NUMBER (WITHIN THAT SUBTYPE). --- ;
 * -------------------------------------------------------------- ;

DATA OUT1.&OUTFILE1.
                 (KEEP=KEY FIPST FIPSTCO DRG DRGVER MDC YEAR DQTR 
                       AGECAT AGECCAT POPCAT SEXCAT RACECAT DUALCAT
                       TAPQ01--TAPQ16 TAPQ90-TAPQ92);
 SET IN0.&INFILE0.
                 (KEEP=KEY DRG DRGVER MDC SEX AGE AGEDAY PSTCO 
                       RACE YEAR DQTR PAY1 PAY2 
                       ASOURCE POINTOFORIGINUB04 ATYPE 
                       DX1-DX&NDX. PR1-PR&NPR. DISCWT);

 * -------------------------------------------------------------- ;
 * --- DIAGNOSIS AND PROCEDURE MACROS --------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO MDX(FMT);

 (%DO I = 1 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO MDX1(FMT);

 ((PUT(DX1,&FMT.) = '1'))

 %MEND;

 %MACRO MDX2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (PUT(DX&I.,&FMT.) = '1') OR
  %END;
  (PUT(DX&NDX.,&FMT.) = '1'))

 %MEND;

 %MACRO MPR(FMT);

 (%DO I = 1 %TO &NPR.-1;
  (PUT(PR&I.,&FMT.) = '1') OR
  %END;
  (PUT(PR&NPR.,&FMT.) = '1'))

 %MEND;

 * -------------------------------------------------------------- ;
 * --- DEFINE MDC                        ------------------------ ;
 * -------------------------------------------------------------- ;
 ATTRIB MDCNEW LENGTH=3
   LABEL='IMPUTED MDC';

 IF MDC NOTIN (01,02,03,04,05,06,07,08,09,10,
               11,12,13,14,15,16,17,18,19,20,
               21,22,23,24,25)
 THEN DO;
    IF DRGVER LE 24 THEN MDCNEW = PUT(DRG,MDCFMT.);
    ELSE IF DRGVER GE 25 THEN MDCNEW = PUT(DRG,MDCF2T.);
    IF MDCNEW IN (01,02,03,04,05,06,07,08,09,10,
                  11,12,13,14,15,16,17,18,19,20,
                  21,22,23,24,25)
    THEN MDC=MDCNEW;
    ELSE DO;
       IF DRGVER LE 24 AND DRG IN (470) THEN MDC = 0;
       ELSE IF DRGVER GE 25 AND DRG IN (999) THEN MDC = 0;
       ELSE PUT "INVALID MDC KEY: " KEY " MDC " MDC " DRG " DRG DRGVER;
    END;
 END;
 

 * -------------------------------------------------------------- ;
 * --- DELETE RECORDS WITH MISSING VALUES FOR AGE OR SEX--------- ;
 * --- DELETE NON ADULT RECORDS                         --------- ;
 * -------------------------------------------------------------- ;
 IF SEX LE 0 THEN DELETE;
 IF AGE LT 0 THEN DELETE;
 IF AGE LT 18 AND MDC NOTIN (14) THEN DELETE;
 

 * -------------------------------------------------------------- ;
 * --- SET MISSING DISCHARGE WEIGHT TO ONE              --------- ;
 * -------------------------------------------------------------- ;
 IF DISCWT LT 0 THEN DISCWT = 1;


  * -------------------------------------------------------------- ;
 * --- DEFINE ICD-9-CM VERSION           ------------------------ ;
 * -------------------------------------------------------------- ;
 ATTRIB ICDVER LENGTH=3
   LABEL='ICD-9-CM VERSION';

 ICDVER = 0;
 IF (YEAR IN (1994) AND DQTR IN (4))     THEN ICDVER = 12;
 ELSE IF (YEAR IN (1995) AND DQTR IN (1,2,3)) THEN ICDVER = 12;
 ELSE IF (YEAR IN (1995) AND DQTR IN (4))     THEN ICDVER = 13;
 ELSE IF (YEAR IN (1996) AND DQTR IN (1,2,3)) THEN ICDVER = 13;
 ELSE IF (YEAR IN (1996) AND DQTR IN (4))     THEN ICDVER = 14;
 ELSE IF (YEAR IN (1997) AND DQTR IN (1,2,3)) THEN ICDVER = 14;
 ELSE IF (YEAR IN (1997) AND DQTR IN (4))     THEN ICDVER = 15;
 ELSE IF (YEAR IN (1998) AND DQTR IN (1,2,3)) THEN ICDVER = 15;
 ELSE IF (YEAR IN (1998) AND DQTR IN (4))     THEN ICDVER = 16;
 ELSE IF (YEAR IN (1999) AND DQTR IN (1,2,3)) THEN ICDVER = 16;
 ELSE IF (YEAR IN (1999) AND DQTR IN (4))     THEN ICDVER = 17;
 ELSE IF (YEAR IN (2000) AND DQTR IN (1,2,3)) THEN ICDVER = 17;
 ELSE IF (YEAR IN (2000) AND DQTR IN (4))     THEN ICDVER = 18;
 ELSE IF (YEAR IN (2001) AND DQTR IN (1,2,3)) THEN ICDVER = 18;
 ELSE IF (YEAR IN (2001) AND DQTR IN (4))     THEN ICDVER = 19;
 ELSE IF (YEAR IN (2002) AND DQTR IN (1,2,3)) THEN ICDVER = 19;
 ELSE IF (YEAR IN (2002) AND DQTR IN (4))     THEN ICDVER = 20;
 ELSE IF (YEAR IN (2003) AND DQTR IN (1,2,3)) THEN ICDVER = 20;
 ELSE IF (YEAR IN (2003) AND DQTR IN (4))     THEN ICDVER = 21;
 ELSE IF (YEAR IN (2004) AND DQTR IN (1,2,3)) THEN ICDVER = 21;
 ELSE IF (YEAR IN (2004) AND DQTR IN (4))     THEN ICDVER = 22;
 ELSE IF (YEAR IN (2005) AND DQTR IN (1,2,3)) THEN ICDVER = 22;
 ELSE IF (YEAR IN (2005) AND DQTR IN (4))     THEN ICDVER = 23;
 ELSE IF (YEAR IN (2006) AND DQTR IN (1,2,3)) THEN ICDVER = 23;
 ELSE IF (YEAR IN (2006) AND DQTR IN (4))     THEN ICDVER = 24;
 ELSE IF (YEAR IN (2007) AND DQTR IN (1,2,3)) THEN ICDVER = 24;
 ELSE IF (YEAR IN (2007) AND DQTR IN (4))     THEN ICDVER = 25;
 ELSE IF (YEAR IN (2008) AND DQTR IN (1,2,3)) THEN ICDVER = 25;
 ELSE IF (YEAR IN (2008) AND DQTR IN (4))     THEN ICDVER = 26;
 ELSE IF (YEAR IN (2009) AND DQTR IN (1,2,3)) THEN ICDVER = 26;


* -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES             ----------- ;
 * -------------------------------------------------------------- ;
 ATTRIB FIPSTCO LENGTH=$5
   LABEL='FIPS STATE COUNTY CODE';
 FIPSTCO = PUT(PSTCO,Z5.);

 ATTRIB FIPST LENGTH=$2
   LABEL='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 ATTRIB PAYCAT LENGTH=3
   LABEL='PATIENT PRIMARY PAYER';

 SELECT (PAY1);
   WHEN (1)  PAYCAT = 1;
   WHEN (2)  PAYCAT = 2;
   WHEN (3)  PAYCAT = 3;
   WHEN (4)  PAYCAT = 4;
   WHEN (5)  PAYCAT = 5;
   OTHERWISE PAYCAT = 6;
 END; * SELECT PAY1 ;

 ATTRIB DUALCAT LENGTH=3
   LABEL='PATIENT DUAL ELIGIBLE';

 IF (PAY1 IN (1) AND PAY2 IN (2)) OR
    (PAY1 IN (2) AND PAY2 IN (1)) 
 THEN DUALCAT = 1; ELSE DUALCAT = 0;
    

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB RACECAT LENGTH=3
   LABEL='PATIENT RACE/ETHNICITY';

 SELECT (RACE);
   WHEN (1)  RACECAT = 1;
   WHEN (2)  RACECAT = 2;
   WHEN (3)  RACECAT = 3;
   WHEN (4)  RACECAT = 4;
   WHEN (5)  RACECAT = 5;
   OTHERWISE RACECAT = 6;
 END; * SELECT RACE ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB AGECAT LENGTH=3
   LABEL='PATIENT AGE';

 SELECT;
   WHEN (      AGE < 18)  AGECAT = 0;
   WHEN (18 <= AGE < 40)  AGECAT = 1;
   WHEN (40 <= AGE < 65)  AGECAT = 2;
   WHEN (65 <= AGE < 75)  AGECAT = 3;
   WHEN (75 <= AGE     )  AGECAT = 4;
 END; * SELECT AGE ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: CONDITION SPECIFIC AGE CATEGORY  ------ ;
 * -------------------------------------------------------------- ;
 ATTRIB AGECCAT LENGTH=3
   LABEL='PATIENT AGE';

 SELECT;
   WHEN (      AGE < 18)  AGECCAT = 0;
   WHEN (18 <= AGE < 45)  AGECCAT = 1;
   WHEN (45 <= AGE < 65)  AGECCAT = 2;
   WHEN (65 <= AGE < 75)  AGECCAT = 3;
   WHEN (75 <= AGE     )  AGECCAT = 4;
 END; * SELECT CONDITION SPECIFIC AGE ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB SEXCAT LENGTH=3
   LABEL='PATIENT GENDER';

 SELECT (SEX);
   WHEN (1)  SEXCAT = 1;
   WHEN (2)  SEXCAT = 2;
 END; * SELECT SEX ;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 ATTRIB POPCAT LENGTH=3
   LABEL='PATIENT AGE';

 POPCAT=PUT(AGE,AGEFMT.);


 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL ACSC INDICATORS ------------------------ ;
 * -------------------------------------------------------------- ;

 LENGTH TAPQ01 TAPQ02 TAPQ03 TAPQ05
        TAPQ07 TAPQ08 TAPQ10 TAPQ11 
        TAPQ12 TAPQ13 TAPQ14 TAPQ15
        TAPQ16 TAPQ90 TAPQ91 TAPQ92 3;

 LABEL
 TAPQ01 = 'DIABETES SHORT TRM COMPLICATN (Numeratr)'
 TAPQ02 = 'PERFORATED APPENDIX           (Numeratr)'
 TAPQ03 = 'DIABETES LONG TERM COMPLICATN (Numeratr)'
 TAPQ05 = 'COPD                          (Numeratr)'
 TAPQ07 = 'HYPERTENSION                  (Numeratr)'
 TAPQ08 = 'CONGESTIVE HEART FAILURE      (Numeratr)'
 TAPQ10 = 'DEHYDRATION                   (Numeratr)'
 TAPQ11 = 'BACTERIAL PNEUMONIA           (Numeratr)'
 TAPQ12 = 'URINARY INFECTION             (Numeratr)'
 TAPQ13 = 'ANGINA                        (Numeratr)'
 TAPQ14 = 'DIABETES UNCONTROLLED         (Numeratr)'
 TAPQ15 = 'ADULT ASTHMA                  (Numeratr)'
 TAPQ16 = 'LOWER EXTREMITY AMPUTATION    (Numeratr)'
 TAPQ90 = 'OVERALL PQI                   (Numeratr)'
 TAPQ91 = 'ACUTE PQI                     (Numeratr)'
 TAPQ92 = 'CHRONIC PQI                   (Numeratr)'
 ;

 * -------------------------------------------------------------- ;
 * --- CONSTRUCT AREA LEVEL ACSC INDICATORS --------------------- ;
 * -------------------------------------------------------------- ;

   * --- DIABETES SHORT TERM COMPLICATION  --- ;

   IF %MDX1($ACDIASD.) THEN

        TAPQ01 = 1;


   * --- PERFORATED APPENDIX               --- ;

   IF %MDX($ACSAP2D.) THEN DO;

      TAPQ02 = 0;

      IF %MDX($ACSAPPD.) THEN TAPQ02 = 1;

      *** Exclude: MDC 14;
      IF MDC IN (14) THEN TAPQ02 = .;

   END;


   * --- DIABETES LONG TERM COMPLICATION   --- ;

   IF %MDX1($ACDIALD.) THEN

        TAPQ03 = 1;


   * --- COPD                              --- ;

   IF %MDX1($ACCOPDD.) OR
      (%MDX1($ACCPD2D.) AND %MDX2($ACCOPDD.))
   THEN

        TAPQ05 = 1;


   * --- HYPERTENSION                      --- ;

   IF %MDX1($ACSHYPD.) THEN DO;

        TAPQ07 = 1;

      ***Exclude Stage I-IV Kidney Disease
         with dialysis access procedures;
      IF %MDX($ACSHY2D.) AND %MPR($ACSHYPP.)
      THEN TAPQ07 = .;

      *** Exclude Cardiac Procedures;
      IF %MPR($ACSCARP.) THEN TAPQ07 = .;

   END;


   * --- CONGESTIVE HEART FAILURE          --- ;

   IF (ICDVER LE 19 AND %MDX1($ACSCHFD.)) OR
      (ICDVER GE 20 AND %MDX1($ACSCH2D.)) 
   THEN DO;

      TAPQ08 = 1;

      *** Exclude Cardiac Procedures;
      IF %MPR($ACSCARP.) THEN TAPQ08 = .;

   END;


   * --- DEHYDRATION                       --- ;

   IF %MDX1($ACSDEHD.) THEN

      TAPQ10 = 1;


   * --- BACTERIAL PNEUMONIA               --- ;

   IF %MDX1($ACSBACD.) THEN DO;

      TAPQ11 = 1;

      *** Exclude: Sickle Cell;
      IF %MDX($ACSBA2D.)  THEN TAPQ11 = .;

      *** Exclude Immunocompromised state;
      IF %MDX($IMMUNID.) OR %MPR($IMMUNIP.) 
      THEN TAPQ11 = .;

   END;
      

   * --- URINARY INFECTION                 --- ;

   IF  %MDX1($ACSUTID.) THEN DO;

      TAPQ12 = 1;

      *** Exclude Immunocompromised state and 
          Kidney/Urinary Tract Disorder;
      IF %MDX($IMMUNID.) OR %MPR($IMMUNIP.) OR 
         %MDX($KIDNEY.) 
      THEN TAPQ12 = .;

   END;

   * --- ANGINA                            --- ;

   IF %MDX1($ACSANGD.) THEN DO;

      TAPQ13 = 1;

      *** Exclude Cardiac Procedures;
      IF %MPR($ACSCARP.) THEN TAPQ13 = .;

   END;


   * --- DIABETES UNCONTROLLED             --- ;

   IF %MDX1($ACDIAUD.) THEN

      TAPQ14 = 1;


   * --- ADULT ASTHMA                      --- ;

   IF %MDX1($ACSASTD.) THEN DO;

      TAPQ15 = 1;

      *** Exclude Cystic Fibrosis and Anomalies 
          of the Respiratory System;
      IF %MDX($RESPAN.) THEN TAPQ15 = .;

   END;


   * --- LOWER EXTREMITY AMPUTATION       --- ;

   IF %MPR($ACSLEAP.) AND %MDX($ACSLEAD.) THEN DO;

      TAPQ16 = 1;

      *** Exclude: MDC 14;
      IF MDC IN (14) THEN TAPQ16 = .;

      *** Exclude: Trauma;
      IF %MDX($ACLEA2D.) THEN TAPQ16 = .;

   END;


 * -------------------------------------------------------------- ;
 * --- CONSTRUCT AREA LEVEL COMPOSITE INDICATORS ---------------- ;
 * -------------------------------------------------------------- ;

   * --- OVERALL                          --- ;

   IF TAPQ01 = 1 OR TAPQ03 = 1 OR TAPQ05 = 1 OR TAPQ07 = 1 OR
      TAPQ08 = 1 OR TAPQ10 = 1 OR TAPQ11 = 1 OR TAPQ12 = 1 OR
      TAPQ13 = 1 OR TAPQ14 = 1 OR TAPQ15 = 1 OR TAPQ16 = 1
   THEN 
   TAPQ90 = MAX(OF TAPQ01 TAPQ03 TAPQ05 TAPQ07 
                   TAPQ08 TAPQ10 TAPQ11 TAPQ12
                   TAPQ13 TAPQ14 TAPQ15 TAPQ16);

   * --- ACUTE                            --- ;

   IF TAPQ10 = 1 OR TAPQ11 = 1 OR TAPQ12 = 1 
   THEN 
   TAPQ91 = MAX(OF TAPQ10 TAPQ11 TAPQ12);

   * --- CHRONIC                          --- ;

   IF TAPQ01 = 1 OR TAPQ03 = 1 OR TAPQ05 = 1 OR TAPQ07 = 1 OR
      TAPQ08 = 1 OR TAPQ13 = 1 OR TAPQ14 = 1 OR TAPQ15 = 1 OR
      TAPQ16 = 1
   THEN 
   TAPQ92 = MAX(OF TAPQ01 TAPQ03 TAPQ05 TAPQ07 
                   TAPQ08 TAPQ13 TAPQ14 TAPQ15
                   TAPQ16);

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ---------------- ;
 IF ASOURCE IN (2,3) OR POINTOFORIGINUB04 IN ('4','5','6')
 THEN DO;
   TAPQ01 = .;
   TAPQ02 = .;
   TAPQ03 = .;
   TAPQ05 = .;
   TAPQ07 = .;
   TAPQ08 = .;
   TAPQ10 = .;
   TAPQ11 = .;
   TAPQ12 = .;
   TAPQ13 = .;
   TAPQ14 = .;
   TAPQ15 = .;
   TAPQ16 = .;
   TAPQ90 = .;
   TAPQ91 = .;
   TAPQ92 = .;
 END;

RUN;

PROC MEANS DATA=OUT1.&OUTFILE1. N NMISS MIN MAX MEAN SUM;
RUN;

PROC CONTENTS DATA=OUT1.&OUTFILE1. POSITION;
RUN;

PROC PRINT DATA=OUT1.&OUTFILE1.(OBS=24);
TITLE4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE1.";
RUN;

