*============================================================================;
*  Title:
*         Format Library for Prevention Indicators Program;
*
*  Description:
*          FORMAT LIB FOR AHRQ PREVENTION INDICATORS;
*
*          >>>  VERSION 4.1, December 2009 <<<
*
*          Note:  Codes valid from 10/1/1994 to 9/30/2009
*
*============================================================================;
FILENAME CONTROL 'C:\PATHNAME\CONTROL_PQI.SAS'; *<===USER MUST modify;

%INCLUDE CONTROL;


PROC FORMAT DDNAME=library;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
VALUE SEXCAT
 1 = 'Male'
 2 = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
VALUE AGECAT
 0 = '00 to 17'
 1 = '18 to 39'
 2 = '40 to 64'
 3 = '65 to 74'
 4 = '75+'
  ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
VALUE RACECAT
 1 = 'White'
 2 = 'Black'
 3 = 'Hispanic'
 4 = 'Asian and NH/PI'
 5 = 'Amer Indian/AN'
 6 = 'Other'
  ;

 /* --- FORMAT FOR CONDITION SPECIFIC AGE CATEGORY ---------------- */
VALUE AGECCAT
 0 = '00 to 17'
 1 = '18 to 44'
 2 = '45 to 64'
 3 = '65 to 74'
 4 = '75+'
  ;

 * -------------------------------------------------------------- ;
 * --- QI DEFINING FORMATS -------------------------------------- ;
 * -------------------------------------------------------------- ;


 * -------------------------------------------------------------- ;
 * --- FORMATS - AREA LEVEL ACSC INDICATORS --------------------- ;
 * -------------------------------------------------------------- ;

 /* ---------------------------------------------- */
 /* Diabetes short term complication rate (ACDIAS) */
 /*   ACSC #1                                      */
 /* ---------------------------------------------- */

 /* Diabetes with Short Term Complications */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACDIASD
'25010' = 1  /* DM KETO T2, DM CONT */
'25011' = 1  /* DM KETO T1, DM CONT */
'25012' = 1  /* DM KETO T2, DM UNCONT */
'25013' = 1  /* DM KETO T1, DM UNCONT */
'25020' = 1  /* DM W/ HYPROSM T2, DM CONT */
'25021' = 1  /* DM W/ HYPROSM T1, DM CONT */
'25022' = 1  /* DM W/ HYPROSM T2, DM UNCNT */
'25023' = 1  /* DM W/ HYPROSM T1, DM UNCNT */
'25030' = 1  /* DM COMA NEC TYP II, DM CNT */
'25031' = 1  /* DM COMA NEC T1, DM CONT */
'25032' = 1  /* DM COMA NEC T2, DM UNCONT */
'25033' = 1  /* DM COMA NEC T1, DM UNCONT */
OTHER   = 0 ;

 /* --------------------------------- */
 /* Perforated Appendix rate (ACSAPP) */
 /*   ACSC #2                         */
 /* --------------------------------- */

 /* Perforated Appendix (Outcome of Interest) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSAPPD
'5400 ' = 1  /* AC APPEND W PERITONITIS */
'5401 ' = 1  /* ABSCESS OF APPENDIX */
OTHER   = 0 ;

 /* Appendicitis (Population at Risk) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSAP2D
'5400 ' = 1  /* AC APPEND W PERITONITIS */
'5401 ' = 1  /* ABSCESS OF APPENDIX */
'5409 ' = 1  /* ACUTE APPENDICITIS NOS */
'541  ' = 1  /* APPENDICITIS NOS */
OTHER   = 0 ;


 /* --------------------------------------------- */
 /* Diabetes long term complication rate (ACDIAL) */
 /*   ACSC #3                                     */
 /* --------------------------------------------- */

 /* Diabetes with Long Term Complications */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACDIALD
'25040' = 1  /* DM RENAL COMP T2 CONT */
'25041' = 1  /* DM RENAL COMP T1 CONT */
'25042' = 1  /* DM RENAL COMP T2 UNCNT */
'25043' = 1  /* DM RENAL COMP T1 UNCNT */
'25050' = 1  /* DM EYE COMP T2 CONT */
'25051' = 1  /* DM EYE COMP T1 CONT */
'25052' = 1  /* DM EYE COMP T2 UNCNT */
'25053' = 1  /* DM EYE COMP T1 UNCNT */
'25060' = 1  /* DM NEURO COMP T2 CONT */
'25061' = 1  /* DM NEURO COMP T1 CONT */
'25062' = 1  /* DM NEURO COMP T2 UNCNT */
'25063' = 1  /* DM NEURO COMP T1 UNCNT */
'25070' = 1  /* DM CIRCU DIS T2 CONT */
'25071' = 1  /* DM CIRCU DIS T1 CONT */
'25072' = 1  /* DM CIRCU DIS T2 UNCNT */
'25073' = 1  /* DM CIRCU DIS T1 UNCNT */
'25080' = 1  /* DM W COMP NEC T2 CONT */
'25081' = 1  /* DM W COMP NEC T1 CONT */
'25082' = 1  /* DM W COMP NEC T2 UNCNT */
'25083' = 1  /* DM W COMP NEC T1 UNCNT */
'25090' = 1  /* DM W COMPL NOS T2 CONT */
'25091' = 1  /* DM W COMPL NOS T1 CONT */
'25092' = 1  /* DM W COMPL NOS T2 UNCNT */
'25093' = 1  /* DM W COMPL NOS T1 UNCNT */
OTHER   = 0 ;

 /* --------------------- */
 /* Asthma rate (ACSAST)  */
 /*   ACSC #15 - Adult    */
 /* --------------------- */

 /* Asthma                    */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSASTD
'49300' = 1  /* EXT ASTHMA W/O STAT ASTH */
'49301' = 1  /* EXT ASTHMA W STATUS ASTH */
'49302' = 1  /* EXT ASTHMA W ACUTE EXAC */
'49310' = 1  /* INT ASTHMA W/O STAT ASTH */
'49311' = 1  /* INT ASTHMA W STATUS ASTH */
'49312' = 1  /* INT ASTHMA W ACUTE EXAC */
'49320' = 1  /* CH OB ASTH W/O STAT ASTH */
'49321' = 1  /* CH OB ASTHMA W STAT ASTH */
'49322' = 1  /* CH OBS ASTH W ACUTE EXAC */
'49381' = 1  /* EXERCSE IND BRONCHOSPASM */
'49382' = 1  /* COUGH VARIANT ASTHMA */
'49390' = 1  /* ASTHMA W/O STATUS ASTHM */
'49391' = 1  /* ASTHMA W STATUS ASTHMAT */
'49392' = 1  /* ASTHMA W ACUTE EXACERBTN */
OTHER   = 0 ;

 /* EXCLUDE: CYSTIC FIBROSIS AND ANOMALIES OF RESPIRATORY SYSTEM */
 /* ICD-9-CM DIAGNOSIS CODES */

VALUE $RESPAN
'27700' = 1  /* CYSTIC FIBROS W/O ILEUS */
'27701' = 1  /* CYSTIC FIBROS W ILEUS */
'27702' = 1  /* CYSTIC FIBROS W PUL MAN */
'27703' = 1  /* CYSTIC FIBROSIS  W GI MAN */
'27709' = 1  /* CYSTIC FIBROSIS NEC */
'74721' = 1  /* ANOMALIES OF AORTIC ARCH */
'7483 ' = 1  /* LARYNGOTRACH ANOMALY NEC */
'7484 ' = 1  /* CONGENITAL CYSTIC LUNG */
'7485 ' = 1  /* AGENESIS OF LUNG */
'74860' = 1  /* LUNG ANOMALY NOS */
'74861' = 1  /* CONGEN BRONCHIECTASIS */
'74869' = 1  /* LUNG ANOMALY NEC */
'7488 ' = 1  /* RESPIRATORY ANOMALY NEC */
'7489 ' = 1  /* RESPIRATORY ANOMALY NOS */
'7503 ' = 1  /* CONG ESOPH FISTULA/ATRES */
'7593 ' = 1  /* SITUS INVERSUS */
'7707 ' = 1  /* PERINATAL CHR RESP DIS*/
OTHER   = 0;

 /* ------------------ */
 /* COPD rate (ACCOPD) */
 /*   ACSC #5          */
 /* ------------------ */

 /* COPD (#1) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACCOPDD
'4910 ' = 1  /* SIMPLE CHR BRONCHITIS */
'4911 ' = 1  /* MUCOPURUL CHR BRONCHITIS */
'49120' = 1  /* OBS CHR BRNC W/O ACT EXA */
'49121' = 1  /* OBS CHR BRNC W ACT EXA */
'4918 ' = 1  /* CHRONIC BRONCHITIS NEC */
'4919 ' = 1  /* CHRONIC BRONCHITIS NOS */
'4920 ' = 1  /* EMPHYSEMATOUS BLEB */
'4928 ' = 1  /* EMPHYSEMA NEC */
'494  ' = 1  /* BRONCHIECTASIS */
'4940 ' = 1  /* BRONCHIECTAS W/O AC EXAC */
'4941 ' = 1  /* BRONCHIECTASIS W AC EXAC */
'496  ' = 1  /* CHR AIRWAY OBSTRUCT NEC */
OTHER   = 0 ;

 /* COPD (#2) */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACCPD2D
'4660 ' = 1  /* ACUTE BRONCHITIS */
'490  ' = 1  /* BRONCHITIS NOS */
OTHER   = 0 ;


 /* -------------------------- */
 /* Hypertension rate (ACSHYP) */
 /*   ACSC #7                  */
 /* -------------------------- */

 /* Hypertension */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSHYPD
'4010 ' = 1  /* MALIGNANT HYPERTENSION */
'4019 ' = 1  /* HYPERTENSION NOS */
'40200' = 1  /* MAL HYPERTEN HRT DIS NOS */
'40210' = 1  /* BEN HYPERTEN HRT DIS NOS */
'40290' = 1  /* HYPERTENSIVE HRT DIS NOS */
'40300' = 1  /* MAL HYP REN W/O REN FAIL */
'40310' = 1  /* BEN HYP REN W/O REN FAIL */
'40390' = 1  /* HYP REN NOS W/O REN FAIL */
'40400' = 1  /* MAL HY HT/REN W/O CHF/RF */
'40410' = 1  /* BEN HY HT/REN W/O CHF/RF */
'40490' = 1  /* HY HT/REN NOS W/O CHF/RF */
OTHER   = 0 ;

 /* Exclude: Stage I-IV Kidney Disease */
 /* ICD-9-CM Diagnosis Codes: */
VALUE $ACSHY2D
'40300' = 1  /* MAL HYP REN W/O REN FAIL */
'40310' = 1  /* BEN HYP REN W/O REN FAIL */
'40390' = 1  /* HYP REN NOS W/O REN FAIL */
'40400' = 1  /* MAL HY HT/REN W/O CHF/RF */
'40410' = 1  /* BEN HY HT/REN W/O CHF/RF */
'40490' = 1  /* HY HT/REN NOS W/O CHF/RF */
OTHER   = 0 ;

 /* ICD-9-CM Procedure codes: */
VALUE $ACSHYPP
'3895' = 1  /* VEN CATH RENAL DIALYSIS */
'3927' = 1  /* DIALYSIS ARTERIOVENOSTOM */
'3929' = 1  /* VASC SHUNT & BYPASS NEC */
'3942' = 1  /* REVIS REN DIALYSIS SHUNT */
'3943' = 1  /* REMOV REN DIALYSIS SHUNT */
'3993' = 1  /* INSERT VES-TO-VES CANNUL */
'3994' = 1  /* REPLAC VES-TO-VES CANNUL */
OTHER   = 0 ;

 /* Exclude: Cardiac Procedures */
 /* ICD-9-CM Procedure codes: */

VALUE $ACSCARP
'0050' = 1  /* IMPL CRT PACEMAKER SYS */
'0051' = 1  /* IMPL CRT DEFIBRILLAT SYS */
'0052' = 1  /* IMP/REP LEAD LF VEN SYS */
'0053' = 1  /* IMP/REP CRT PACEMAKR GEN */
'0054' = 1  /* IMP/REP CRT DEFIB GENAT */
'0056' = 1  /* INS/REP IMPL SENSOR LEAD */
'0057' = 1  /* IMP/REP SUBCUE CARD DEV */
'0066' = 1  /* PTCA                    */
'3500' = 1  /* CLOSED VALVOTOMY NOS */
'3501' = 1  /* CLOSED AORTIC VALVOTOMY */
'3502' = 1  /* CLOSED MITRAL VALVOTOMY */
'3503' = 1  /* CLOSED PULMON VALVOTOMY */
'3504' = 1  /* CLOSED TRICUSP VALVOTOMY */
'3510' = 1  /* OPEN VALVULOPLASTY NOS */
'3511' = 1  /* OPN AORTIC VALVULOPLASTY */
'3512' = 1  /* OPN MITRAL VALVULOPLASTY */
'3513' = 1  /* OPN PULMON VALVULOPLASTY */
'3514' = 1  /* OPN TRICUS VALVULOPLASTY */
'3520' = 1  /* REPLACE HEART VALVE NOS */
'3521' = 1  /* REPLACE AORT VALV-TISSUE */
'3522' = 1  /* REPLACE AORTIC VALVE NEC */
'3523' = 1  /* REPLACE MITR VALV-TISSUE */
'3524' = 1  /* REPLACE MITRAL VALVE NEC */
'3525' = 1  /* REPLACE PULM VALV-TISSUE */
'3526' = 1  /* REPLACE PULMON VALVE NEC */
'3527' = 1  /* REPLACE TRIC VALV-TISSUE */
'3528' = 1  /* REPLACE TRICUSP VALV NEC */
'3531' = 1  /* PAPILLARY MUSCLE OPS */
'3532' = 1  /* CHORDAE TENDINEAE OPS */
'3533' = 1  /* ANNULOPLASTY */
'3534' = 1  /* INFUNDIBULECTOMY */
'3535' = 1  /* TRABECUL CARNEAE CORD OP */
'3539' = 1  /* TISS ADJ TO VALV OPS NEC */
'3541' = 1  /* ENLARGE EXISTING SEP DEF */
'3542' = 1  /* CREATE SEPTAL DEFECT */
'3550' = 1  /* PROSTH REP HRT SEPTA NOS */
'3551' = 1  /* PROS REP ATRIAL DEF-OPN */
'3552' = 1  /* PROS REPAIR ATRIA DEF-CL */
'3553' = 1  /* PROST REPAIR VENTRIC DEF */
'3554' = 1  /* PROS REP ENDOCAR CUSHION */
'3555' = 1  /* PROS REP VENTRC DEF-CLOS */
'3560' = 1  /* GRFT REPAIR HRT SEPT NOS */
'3561' = 1  /* GRAFT REPAIR ATRIAL DEF */
'3562' = 1  /* GRAFT REPAIR VENTRIC DEF */
'3563' = 1  /* GRFT REP ENDOCAR CUSHION */
'3570' = 1  /* HEART SEPTA REPAIR NOS */
'3571' = 1  /* ATRIA SEPTA DEF REP NEC */
'3572' = 1  /* VENTR SEPTA DEF REP NEC */
'3573' = 1  /* ENDOCAR CUSHION REP NEC */
'3581' = 1  /* TOT REPAIR TETRAL FALLOT */
'3582' = 1  /* TOTAL REPAIR OF TAPVC */
'3583' = 1  /* TOT REP TRUNCUS ARTERIOS */
'3584' = 1  /* TOT COR TRANSPOS GRT VES */
'3591' = 1  /* INTERAT VEN RETRN TRANSP */
'3592' = 1  /* CONDUIT RT VENT-PUL ART */
'3593' = 1  /* CONDUIT LEFT VENTR-AORTA */
'3594' = 1  /* CONDUIT ARTIUM-PULM ART */
'3595' = 1  /* HEART REPAIR REVISION */
'3596' = 1  /* PERC HEART VALVULOPLASTY */
'3598' = 1  /* OTHER HEART SEPTA OPS */
'3599' = 1  /* OTHER HEART VALVE OPS */
'3601' = 1  /* PTCA-1 VESSEL W/O AGENT */
'3602' = 1  /* PTCA-1 VESSEL WITH AGNT */
'3603' = 1  /* OPEN CORONRY ANGIOPLASTY */
'3604' = 1  /* INTRCORONRY THROMB INFUS */
'3605' = 1  /* PTCA-MULTIPLE VESSEL */
'3606' = 1  /* INSERT OF COR ART STENT */
'3607' = 1  /* INS DRUG-ELUT CORONRY ST */
'3609' = 1  /* REM OF COR ART OBSTR NEC */
'3610' = 1  /* AORTOCORONARY BYPASS NOS */
'3611' = 1  /* AORTOCOR BYPAS-1 COR ART */
'3612' = 1  /* AORTOCOR BYPAS-2 COR ART */
'3613' = 1  /* AORTOCOR BYPAS-3 COR ART */
'3614' = 1  /* AORTCOR BYPAS-4+ COR ART */
'3615' = 1  /* 1 INT MAM-COR ART BYPASS */
'3616' = 1  /* 2 INT MAM-COR ART BYPASS */
'3617' = 1  /* ABD-CORON ART BYPASS */
'3619' = 1  /* HRT REVAS BYPS ANAS NEC */
'362 ' = 1  /* ARTERIAL IMPLANT REVASC */
'363 ' = 1  /* OTH HEART REVASCULAR */
'3631' = 1  /* OPEN CHEST TRANS REVASC */
'3632' = 1  /* OTH TRANSMYO REVASCULAR */
'3633' = 1  /* ENDO TRANSMYO REVASCULAR */
'3634' = 1  /* PERC TRANSMYO REVASCULAR */
'3639' = 1  /* OTH HEART REVASCULAR */
'3691' = 1  /* CORON VESS ANEURYSM REP */
'3699' = 1  /* HEART VESSEL OP NEC */
'3731' = 1  /* PERICARDIECTOMY */
'3732' = 1  /* HEART ANEURYSM EXCISION */
'3733' = 1  /* EXC/DEST HRT LESION OPEN */
'3734' = 1  /* EXC/DEST HRT LES OTHER */
'3735' = 1  /* PARTIAL VENTRICULECTOMY */
'3736' = 1 /* EXC LEFT ATRIAL APPENDAG */
'3741' = 1  /* IMPLANTATION            */
'375 ' = 1  /* HEART TRANSPLANTATION */
'3751' = 1  /* HEART TRANSPLANTATION */
'3752' = 1  /* IMPLANT TOT REP HRT SYS */
'3753' = 1  /* REPL/REP THORAC UNIT HRT */
'3754' = 1  /* REPL/REP OTH TOT HRT SYS */
'3755' = 1 /* REM INT BIVENT HRT SYS */
'3760' = 1 /* IMP BIVN EXT HRT AST SYS */
'3761' = 1  /* PULSATION BALLOON IMPLAN */
'3762' = 1  /* INSRT NON-IMPL CIRC DEV */
'3763' = 1  /* REPAIR HEART ASSIST SYS */
'3764' = 1  /* REMVE EXT HRT ASSIST SYS */
'3765' = 1  /* IMP VENT EXT HRT AST SYS */
'3766' = 1  /* IMPLANTABLE HRT ASSIST */
'3770' = 1  /* INT INSERT PACEMAK LEAD */
'3771' = 1  /* INT INSERT LEAD IN VENT */
'3772' = 1  /* INT INSER LEAD ATRI-VENT */
'3773' = 1  /* INT INSER LEAD IN ATRIUM */
'3774' = 1  /* INT OR REPL LEAD EPICAR */
'3775' = 1  /* REVISION OF LEAD */
'3776' = 1  /* REPL TV ATRI-VENT LEAD */
'3777' = 1  /* REMOVAL OF LEAD W/O REPL */
'3778' = 1  /* INSER TEMP PACEMAKER SYS */
'3779' = 1  /* REVIS OR RELOCATE POCKET */
'3780' = 1  /* INT OR REPL PERM PACEMKR */
'3781' = 1  /* INT INSERT 1-CHAM, NON */
'3782' = 1  /* INT INSERT 1-CHAM, RATE */
'3783' = 1  /* INT INSERT DUAL-CHAM DEV */
'3785' = 1  /* REPL PACEM W 1-CHAM, NON */
'3786' = 1  /* REPL PACEM 1-CHAM, RATE */
'3787' = 1  /* REPL PACEM W DUAL-CHAM */
'3789' = 1  /* REVISE OR REMOVE PACEMAK */
'3794' = 1  /* IMPLT/REPL CARDDEFIB TOT */
'3795' = 1  /* IMPLT CARDIODEFIB LEADS */
'3796' = 1  /* IMPLT CARDIODEFIB GENATR */
'3797' = 1  /* REPL CARDIODEFIB LEADS */
'3798' = 1  /* REPL CARDIODEFIB GENRATR */
OTHER   = 0 ;


 /* -------------------------------------- */
 /* Congestive Heart Failure rate (ACSCHF) */
 /*   ACSC #8                              */
 /* -------------------------------------- */

 /* CHF */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSCHFD
'39891' = 1  /* RHEUMATIC HEART FAILURE */
'40201' = 1  /* MAL HYPERT HRT DIS W CHF */
'40211' = 1  /* BENIGN HYP HRT DIS W CHF */
'40291' = 1  /* HYPERTEN HEART DIS W CHF */
'40401' = 1  /* MAL HYPER HRT/REN W CHF */
'40403' = 1  /* MAL HYP HRT/REN W CHF/RF */
'40411' = 1  /* BEN HYPER HRT/REN W CHF */
'40413' = 1  /* BEN HYP HRT/REN W CHF/RF */
'40491' = 1  /* HYPER HRT/REN NOS W CHF */
'40493' = 1  /* HYP HT/REN NOS W CHF/RF */
'4280 ' = 1  /* CONGESTIVE HEART FAILURE */
'4281 ' = 1  /* LEFT HEART FAILURE */
'42820' = 1  /* SYSTOLIC HRT FAILURE NOS */
'42821' = 1  /* AC SYSTOLIC HRT FAILURE */
'42822' = 1  /* CHR SYSTOLIC HRT FAILURE */
'42823' = 1  /* AC ON CHR SYST HRT FAIL */
'42830' = 1  /* DIASTOLC HRT FAILURE NOS */
'42831' = 1  /* AC DIASTOLIC HRT FAILURE */
'42832' = 1  /* CHR DIASTOLIC HRT FAIL */
'42833' = 1  /* AC ON CHR DIAST HRT FAIL */
'42840' = 1  /* SYST/DIAST HRT FAIL NOS */
'42841' = 1  /* AC SYST/DIASTOL HRT FAIL */
'42842' = 1  /* CHR SYST/DIASTL HRT FAIL */
'42843' = 1  /* AC/CHR SYST/DIA HRT FAIL */
'4289 ' = 1  /* HEART FAILURE NOS */
OTHER   = 0 ;

 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSCH2D
'39891' = 1  /* RHEUMATIC HEART FAILURE */
'4280 ' = 1  /* CONGESTIVE HEART FAILURE */
'4281 ' = 1  /* LEFT HEART FAILURE */
'42820' = 1  /* SYSTOLIC HRT FAILURE NOS */
'42821' = 1  /* AC SYSTOLIC HRT FAILURE */
'42822' = 1  /* CHR SYSTOLIC HRT FAILURE */
'42823' = 1  /* AC ON CHR SYST HRT FAIL */
'42830' = 1  /* DIASTOLC HRT FAILURE NOS */
'42831' = 1  /* AC DIASTOLIC HRT FAILURE */
'42832' = 1  /* CHR DIASTOLIC HRT FAIL */
'42833' = 1  /* AC ON CHR DIAST HRT FAIL */
'42840' = 1  /* SYST/DIAST HRT FAIL NOS */
'42841' = 1  /* AC SYST/DIASTOL HRT FAIL */
'42842' = 1  /* CHR SYST/DIASTL HRT FAIL */
'42843' = 1  /* AC/CHR SYST/DIA HRT FAIL */
'4289 ' = 1  /* HEART FAILURE NOS */
OTHER   = 0 ;

 /* Exclude: Cardiac procedures */
 /* ICD-9-CM Procedure Codes:   */
 /* See ACSC #7 Hypertension    */


 /* ------------------------------ */
 /* Low Birth Weight rate (ACSLBW) */
 /*   ACSC #9                      */
 /* ------------------------------ */

 /* Liveborn (Populaton at Risk)           */
 /* ICD-9-CM Diagnosis Codes:              */

VALUE $LIVEBND
'V3000' = 1  /* SINGLE LB IN-HOSP W/O CS */
'V3001' = 1  /* SINGLE LB IN-HOSP W CS */
'V3100' = 1  /* TWIN-MATE LB-HOSP W/O CS */
'V3101' = 1  /* TWIN-MATE LB-IN HOS W CS */
'V3200' = 1  /* TWIN-MATE SB-HOSP W/O CS */
'V3201' = 1  /* TWIN-MATE SB-HOSP W CS */
'V3300' = 1  /* TWIN-NOS-IN HOSP W/O CS */
'V3301' = 1  /* TWIN-NOS-IN HOSP W CS */
'V3400' = 1  /* OTH MULT LB-HOSP W/O CS */
'V3401' = 1  /* OTH MULT LB-IN HOSP W CS */
'V3500' = 1  /* OTH MULT SB-HOSP W/O CS */
'V3501' = 1  /* OTH MULT SB-IN HOSP W CS */
'V3600' = 1  /* MULT LB/SB-IN HOS W/O CS */
'V3601' = 1  /* MULT LB/SB-IN HOSP W CS */
'V3700' = 1  /* MULT BRTH NOS-HOS W/O CS */
'V3701' = 1  /* MULT BIRTH NOS-HOSP W CS */
'V3900' = 1  /* LIVEBORN NOS-HOSP W/O CS */
'V3901' = 1  /* LIVEBORN NOS-HOSP W CS */
OTHER   = 0 ;

VALUE $V29D
"V290"  = "1" /* OBSERVATIONS FOR SUSPECTED INFECTIOUS CONDITION */
"V291"  = "1" /* OBSERVATIONS FOR SUSPECTED NEUROLOGICAL CONDITION */
"V292"  = "1" /* OBSERVATIONS FOR SUSPECTED RESPIRATORY CONDITION */
"V293"  = "1" /* OBSERVATIONS FOR SUSPECTED GENETIC OR METABOLIC CONDITION */
"V298"  = "1" /* OBSERVATIONS FOR OTHER SPECIFIED SUSPECTED CONDITION */
"V299"  = "1" /* OBSERVATIONS FOR UNSPECIFIED SUSPECTED CONDITION */
OTHER   = "0";

VALUE $LIVEB2D
'V301 ' = 1  /* SINGL LIVEBRN-BEFORE ADM */
'V302 ' = 1  /* SINGLE LIVEBORN-NONHOSP */
'V311 ' = 1  /* TWIN, MATE LB-BEFORE ADM */
'V312 ' = 1  /* TWIN, MATE LB-NONHOSP */
'V321 ' = 1  /* TWIN, MATE SB-BEFORE ADM */
'V322 ' = 1  /* TWIN, MATE SB-NONHOSP */
'V331 ' = 1  /* TWIN NOS-BEFORE ADMISSN */
'V332 ' = 1  /* TWIN NOS-NONHOSP */
'V341 ' = 1  /* OTH MULT NB-BEFORE ADM */
'V342 ' = 1  /* OTH MULTIPLE NB-NONHOSP */
'V351 ' = 1  /* OTH MULT SB-BEFORE ADM */
'V352 ' = 1  /* OTH MULTIPLE SB-NONHOSP */
'V361 ' = 1  /* MULT NB/SB-BEFORE ADM */
'V362 ' = 1  /* MULTIPLE NB/SB-NONHOSP */
'V371 ' = 1  /* MULT BRTH NOS-BEFORE ADM */
'V372 ' = 1  /* MULT BIRTH NOS-NONHOSP */
'V391 ' = 1  /* LIVEBORN NOS-BEFORE ADM */
'V392 ' = 1  /* LIVEBORN NOS-NONHOSP */
OTHER   = 0 ;

 /* ------------------------- */
 /* Dehydration rate (ACSDEH) */
 /*   ACSC #10                */
 /* ------------------------- */

 /* Dehydration */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSDEHD
'2765 ' = 1  /* HYPOVOLEMIA */
'27650' = 1  /* VOLUME DEPLETION */
'27651' = 1  /* DEHYDRATION */
'27652' = 1  /* HYPOVOLEMIA */
OTHER   = 0 ;

 /* --------------------------------- */
 /* Bacterial Pneumonia rate (ACSBAC) */
 /*   ACSC #11                        */
 /* --------------------------------- */

 /* Bacterial Pneumonia */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSBACD
'481  ' = 1  /* PNEUMOCOCCAL PNEUMONIA */
'4822 ' = 1  /* H.INFLUENZAE PNEUMONIA */
'48230' = 1  /* STREP PNEUMONIA UNSPEC */
'48231' = 1  /* GRP A STREP PNEUMONIA */
'48232' = 1  /* GRP B STREP PNEUMONIA */
'48239' = 1  /* OTH STREP PNEUMONIA */
'48241' = 1 /* METH SUS PNEUM D/T STAPH */
'48242' = 1 /* METH RES PNEU D/T STAPH */
'4829 ' = 1  /* BACTERIAL PNEUMONIA NOS */
'4830 ' = 1  /* MYCOPLASMA PNEUMONIA */
'4831 ' = 1  /* CHLAMYDIA PNEUMONIA */
'4838 ' = 1  /* OTH SPEC ORG PNEUMONIA */
'485  ' = 1  /* BRONCOPNEUMONIA ORG NOS */
'486  ' = 1  /* PNEUMONIA, ORGANISM NOS */
OTHER   = 0 ;

 /* Exclude: Sickle Cell      */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSBA2D
'28241' = 1  /* THLASEMA HB-S W/O CRISIS */
'28242' = 1  /* THLASSEMIA HB-S W CRISIS */
'28260' = 1  /* SICKLE-CELL ANEMIA NOS */
'28261' = 1  /* HB-S DISEASE W/O CRISIS */
'28262' = 1  /* HB-S DISEASE WITH CRISIS */
'28263' = 1  /* SICKLE-CELL/HB-C DISEASE */
'28264' = 1  /* HB-S/HB-C DIS W CRISIS */
'28268' = 1  /* HB-S DIS W/O CRISIS NEC */
'28269' = 1  /* SICKLE-CELL ANEMIA NEC */
OTHER   = 0 ;

 /* ------------------------------- */
 /* Urinary Infection rate (ACSUTI) */
 /*   ACSC #12                      */
 /* ------------------------------- */

 /* Urinary Infection */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSUTID
'59010' = 1  /* AC PYELONEPHRITIS NOS */
'59011' = 1  /* AC PYELONEPHR W MED NECR */
'5902 ' = 1  /* RENAL/PERIRENAL ABSCESS */
'5903 ' = 1  /* PYELOURETERITIS CYSTICA */
'59080' = 1  /* PYELONEPHRITIS NOS */
'59081' = 1  /* PYELONEPHRIT IN OTH DIS */
'5909 ' = 1  /* INFECTION OF KIDNEY NOS */
'5950 ' = 1  /* ACUTE CYSTITIS */
'5959 ' = 1  /* CYSTITIS NOS */
'5990 ' = 1  /* URIN TRACT INFECTION NOS */
OTHER   = 0 ;

 /* EXCLUDE: IMMUNOCOMPROMISED */
 /* ICD-9-CM DIAGNOSIS CODES (INCLUDES ALL 4TH AND 5TH DIGITS) */

VALUE $IMMUNID
"042"   = "1" /* HUMAN IMMUNODEFICIENCY VIRUS DISEASE */
"1363"  = "1" /* PNEUMOCYSTOSIS */
"1992"  = "1" /* MALIG NEOPL-TRANSP ORGAN */
"23873" = "1" /* HI GRDE MYELODYS SYN LES */
"23876" = "1" /* MYELOFI W MYELO METAPLAS */
"23877" = "1" /* POST TP LYMPHPROLIF DIS */
"23879" = "1" /* LYMPH/HEMATPOITC TIS NEC */
"260  " = "1" /* KWASHIORKOR */
"261  " = "1" /* NUTRITIONAL MARASMUS */
"262  " = "1" /* OTH SEVERE MALNUTRITION */
"27900" = "1" /* HYPOGAMMAGLOBULINEM NOS */
"27901" = "1" /* SELECTIVE IGA IMMUNODEF */
"27902" = "1" /* SELECTIVE IGM IMMUNODEF */
"27903" = "1" /* SELECTIVE IG DEFIC NEC */
"27904" = "1" /* CONG HYPOGAMMAGLOBULINEM */
"27905" = "1" /* IMMUNODEFIC W HYPER-IGM */
"27906" = "1" /* COMMON VARIABL IMMUNODEF */
"27909" = "1" /* HUMORAL IMMUNITY DEF NEC */
"27910" = "1" /* IMMUNDEF T-CELL DEF NOS */
"27911" = "1" /* DIGEORGES SYNDROME */
"27912" = "1" /* WISKOTT-ALDRICH SYNDROME */
"27913" = "1" /* NEZELOFS SYNDROME */
"27919" = "1" /* DEFIC CELL IMMUNITY NOS */
"2792"  = "1" /* COMBINED IMMUNITY DEFICIENCY */
"2793"  = "1" /* UNSPECIFIED IMMUNITY DEFICIENCY */
"2794"  = "1" /* AUTOIMMUNE DISEASE, NOT ELSEWHERE CLASSIFIED */
"27950" = "1" /* GRAFT-VERSUS-HOST NOS */
"27951" = "1" /* AC GRAFT-VERSUS-HOST DIS */
"27952" = "1" /* CHRONC GRAFT-VS-HOST DIS */
"27953" = "1" /* AC ON CHRN GRFT-VS-HOST */
"2798"  = "1" /* OTHER SPECIFIED DISORDERS INVOLVING THE IMMUNE MECHANISM */
"2799"  = "1" /* UNSPECIFIED DISORDER OF IMMUNE MECHANISM */
"28409" = "1" /* CONST APLASTC ANEMIA NEC */
"2841 " = "1" /* PANCYTOPENIA */
"2880 " = "1" /* AGRANULOCYTOSIS */
"28800" = "1" /* NEUTROPENIA NOS */
"28801" = "1" /* CONGENITAL NEUTROPENIA */
"28802" = "1" /* CYCLIC NEUTROPENIA */
"28803" = "1" /* DRUG INDUCED NEUTROPENIA */
"28809" = "1" /* NEUTROPENIA NEC */
"2881 " = "1" /* FUNCTION DIS NEUTROPHILS */
"2882 " = "1" /* GENETIC ANOMALY LEUKOCYT */
"2884 " = "1" /* HEMOPHAGOCYTIC SYNDROMES */
"28850" = "1" /* LEUKOCYTOPENIA NOS */
"28851" = "1" /* LYMPHOCYTOPENIA */
"28859" = "1" /* DECREASED WBC COUNT NEC */
"28953" = "1" /* NEUTROPENIC SPLENOMEGALY */
"28983" = "1" /* MYELOFIBROSIS */
"40301" = "1" /* MAL HYP KIDNEY W CHR KID */
"40311" = "1" /* BEN HYP KIDNEY W CHR KID */
"40391" = "1" /* HYP KIDNEY NOS W CHR KID */
"40402" = "1" /* MAL HY HRT/KID W CHR KID */
"40403" = "1" /* MAL HYP HRT/KID W HF/KID */
"40412" = "1" /* BEN HYP HT/KID W CHR KID */
"40413" = "1" /* BEN HYP HT/KID W HF/KID */
"40492" = "1" /* HYP HT/KID NOS W CHR KID */
"40493" = "1" /* HYP HRT/KID NOS W HF/KID */
"5793 " = "1" /* INTEST POSTOP NONABSORB */
"585  " = "1" /* CHRONIC RENAL FAILURE */
"5855 " = "1" /* CHRON KIDNEY DIS STAGE V */
"5856 " = "1" /* END STAGE RENAL DISEASE */
"9968"  = "1" /* COMPLICATIONS OF TRANSPLANTED ORGAN */
"99680" = "1" /* COMP ORGAN TRANSPLNT NOS */
"99681" = "1" /* COMPL KIDNEY TRANSPLANT */
"99682" = "1" /* COMPL LIVER TRANSPLANT */
"99683" = "1" /* COMPL HEART TRANSPLANT */
"99684" = "1" /* COMPL LUNG TRANSPLANT */
"99685" = "1" /* COMPL MARROW TRANSPLANT */
"99686" = "1" /* COMPL PANCREAS TRANSPLNT */
"99687" = "1" /* COMP INTESTINE TRANSPLNT */
"99689" = "1" /* COMP OTH ORGAN TRANSPLNT */
"V420"  = "1" /* KIDNEY REPLACED BY TRANSPLANT */
"V421"  = "1" /* HEART REPLACED BY TRANSPLANT */
"V426"  = "1" /* LUNG REPLACED BY TRANSPLANT */
"V427"  = "1" /* LIVER REPLACED BY TRANSPLANT */
"V428"  = "1" /* OTHER SPECIFIED ORGAN OR TISSUE */
"V4281" = "1" /* BONE MARROW SPECIFIED BY TRANSPLANT */
"V4282" = "1" /* PERIPHERAL STEM CELLS REPLACED BY TRANSPLANT */
"V4283" = "1" /* PANCREAS REPLACED BY TRANSPLANT */
"V4284" = "1" /* INTESTINES REPLACE BY TRANSPLANT */
"V4289" = "1" /* OTHER REPLACED BY TRANSPLANT */
"V451 " = "1" /* RENAL DIALYSIS STATUS */
"V4511" = "1" /* RENAL DIALYSIS STATUS */
"V560 " = "1" /* RENAL DIALYSIS ENCOUNTER */
"V561 " = "1" /* FT/ADJ XTRCORP DIAL CATH */
"V562 " = "1" /* FIT/ADJ PERIT DIAL CATH */
OTHER   = "0" ;

 /* EXCLUDE: IMMUNOCOMPROMISED */
 /* ICD-9-CM PROCEDURE CODES (INCLUDES 4TH AND 5TH DIGITS:) */

VALUE $IMMUNIP
"0018" = "1" /* INFUS IMMUNOSUP ANTIBODY */
"335"  = "1" /* LUNG TRANSPLANT */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336"  = "1" /* COMBINED HEART-LUNG TRANSPLANTATION */
"375"  = "1" /* HEART TRANSPLANTATION */
"3751" = "1" /* HEART TRANSPLANTATION */
"410"  = "1" /* OPERATIONS ON BONE MAROW AND SPLEEN */
"4100" = "1" /* BONE MARROW TRNSPLNT NOS */
"4101" = "1" /* AUTO BONE MT W/O PURG */
"4102" = "1" /* ALO BONE MARROW TRNSPLNT */
"4103" = "1" /* ALLOGRFT BONE MARROW NOS */
"4104" = "1" /* AUTO HEM STEM CT W/O PUR */
"4105" = "1" /* ALLO HEM STEM CT W/O PUR */
"4106" = "1" /* CORD BLD STEM CELL TRANS */
"4107" = "1" /* AUTO HEM STEM CT W PURG */
"4108" = "1" /* ALLO HEM STEM CT W PURG */
"4109" = "1" /* AUTO BONE MT W PURGING */
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5280" = "1" /* PANCREATIC TRANSPLANT, NOS */
"5281" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5282" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5283" = "1" /* HETEROTRANSPLANT OF PANCREAS */
"5285" = "1" /* ALLOTRANSPLANTATION OF CELLS OF ISLETS OF LNGERHANS */
"5286" = "1" /* TRANSPLANTATION OF CELLS OF ISLETS OF LANGERHANS, NOS */
"5569" = "1" /* OTHER KIDNEY TRANSPLANTATION */
OTHER  = "0" ;

 /* EXCLUDE: IMMUNOCOMPROMISED */
 /* DIAGNOSTIC RELATED GROUPS (DRGS): */

VALUE $IMMUNDR
"488" = "1" /* HIV WITH EXTENSIVE OR PROCEDURE */
"489" = "1" /* HIV WITH MAJOR RELATED CONDITION */
"490" = "1" /* HIV WITH OR WITHOUT OTHER RELATED CONDITION */
OTHER = "0" ;

 /* EXCLUDE: KIDNEY OR URINARY TRACT DISORDER */
 /* ICD-9-CM DIAGNOSIS CODES */

VALUE $KIDNEY
'59000' = 1  /* CHR PYELONEPHRITIS NOS */
'59001' = 1  /* CHR PYELONEPH W MED NECR */
'59370' = 1  /* VESCOURETRL RFLUX UNSPCF */
'59371' = 1  /* VESICOURETERAL REFLUX UNILTRL */
'59372' = 1  /* VESICOURETERAL REFLUX NPHT BLTRL */
'59373' = 1  /* VESICOURETERAL REFLUX W NPHT NOS */
'7530 ' = 1  /*  RENAL AGENESIS */
'75310' = 1  /* CYSTIC KIDNEY DISEAS NOS */
'75311' = 1  /* CONGENITAL RENAL CYST */
'75312' = 1  /* POLYCYSTIC KIDNEY NOS */
'75313' = 1  /* POLYCYST KID-AUTOSOM DOM */
'75314' = 1  /* POLYCYST KID-AUTOSOM REC */
'75315' = 1  /* RENAL DYSPLASIA */
'75316' = 1  /* MEDULLARY CYSTIC KIDNEY */
'75317' = 1  /* MEDULLARY SPONGE KIDNEY */
'75319' = 1  /* CYSTIC KIDNEY DISEAS NEC */
'75320' = 1  /* OBS DFCT REN PLV&URT NOS */
'75321' = 1  /* CONGEN OBST URTROPLV JNC */
'75322' = 1  /* CONG OBST URETEROVES JNC */
'75323' = 1  /* CONGENITAL URETEROCELE */
'75329' = 1  /* OBST DEF REN PLV&URT NEC */
'7533 ' = 1  /*  KIDNEY ANOMALY NEC */
'7534 ' = 1  /*  URETERAL ANOMALY NEC */
'7535 ' = 1  /*  EXSTROPHY OF URNIARY BLADDER */
'7536 ' = 1  /*  ATRESIA AND STENOSIS OF URETHRA AND BLADDER NECK */
'7538 ' = 1  /*  CYSTOURETHRAL ANOM NEC */
'7539 ' = 1  /*  URINARY ANOMALY NOS */
OTHER   = 0;

 /* ------------------------------------ */
 /* Angina (w/o procedure) rate (ACSANG) */
 /*   ACSC #13                           */
 /* ------------------------------------ */

 /* Angina */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSANGD
'4111 ' = 1  /* INTERMED CORONARY SYND */
'41181' = 1  /* CORONARY OCCLSN W/O MI */
'41189' = 1  /* AC ISCHEMIC HRT DIS NEC */
'4130 ' = 1  /* ANGINA DECUBITUS */
'4131 ' = 1  /* PRINZMETAL ANGINA */
'4139 ' = 1  /* ANGINA PECTORIS NEC/NOS */
OTHER   = 0 ;

 /* Exclude: Cardiac procedures */
 /* ICD-9-CM Procedure Codes:   */
 /* See ACSC #7 Hypertension    */


 /* ----------------------------------- */
 /* Diabetes uncontrolled rate (ACDIAU) */
 /*   ACSC #14                          */
 /* ----------------------------------- */

 /* Diabetes uncontrolled     */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACDIAUD
'25002' = 1  /* DMII WO CMP UNCNTRLD */
'25003' = 1  /* DMI WO CMP UNCNTRLD */
OTHER   = 0 ;


 /* ----------------------------------------- */
 /* Lower extremity amputation rate (ACSCLEA) */
 /*   ACSC #16                                */
 /* ----------------------------------------- */

 /* Lower extremity amputation */
 /* ICD-9-CM Procedure Codes: */

VALUE $ACSLEAP
'8410' = 1  /* LOWER LIMB AMPUTAT NOS */
'8411' = 1  /* TOE AMPUTATION */
'8412' = 1  /* AMPUTATION THROUGH FOOT */
'8413' = 1  /* DISARTICULATION OF ANKLE */
'8414' = 1  /* AMPUTAT THROUGH MALLEOLI */
'8415' = 1  /* BELOW KNEE AMPUTAT NEC */
'8416' = 1  /* DISARTICULATION OF KNEE */
'8417' = 1  /* ABOVE KNEE AMPUTATION */
'8418' = 1  /* DISARTICULATION OF HIP */
'8419' = 1  /* HINDQUARTER AMPUTATION */
OTHER   = 0 ;

 /* Include only: Diabetes */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACSLEAD
'25000' = 1  /* DMII WO CMP NT ST UNCNTR */
'25001' = 1  /* DMI WO CMP NT ST UNCNTRL */
'25002' = 1  /* DMII WO CMP UNCNTRLD */
'25003' = 1  /* DMI WO CMP UNCNTRLD */
'25010' = 1  /* DMII KETO NT ST UNCNTRLD */
'25011' = 1  /* DMI KETO NT ST UNCNTRLD */
'25012' = 1  /* DMII KETOACD UNCONTROLD */
'25013' = 1  /* DMI KETOACD UNCONTROLD */
'25020' = 1  /* DMII HPRSM NT ST UNCNTRL */
'25021' = 1  /* DMI HPRSM NT ST UNCNTRLD */
'25022' = 1  /* DMII HPROSMLR UNCONTROLD */
'25023' = 1  /* DMI HPROSMLR UNCONTROLD */
'25030' = 1  /* DMII O CM NT ST UNCNTRLD */
'25031' = 1  /* DMI O CM NT ST UNCNTRLD */
'25032' = 1  /* DMII OTH COMA UNCONTROLD */
'25033' = 1  /* DMI OTH COMA UNCONTROLD */
'25040' = 1  /* DMII RENL NT ST UNCNTRLD */
'25041' = 1  /* DMI RENL NT ST UNCNTRLD */
'25042' = 1  /* DMII RENAL UNCNTRLD */
'25043' = 1  /* DMI RENAL UNCNTRLD */
'25050' = 1  /* DMII OPHTH NT ST UNCNTRL */
'25051' = 1  /* DMI OPHTH NT ST UNCNTRLD */
'25052' = 1  /* DMII OPHTH UNCNTRLD */
'25053' = 1  /* DMI OPHTH UNCNTRLD */
'25060' = 1  /* DMII NEURO NT ST UNCNTRL */
'25061' = 1  /* DMI NEURO NT ST UNCNTRLD */
'25062' = 1  /* DMII NEURO UNCNTRLD */
'25063' = 1  /* DMI NEURO UNCNTRLD */
'25070' = 1  /* DMII CIRC NT ST UNCNTRLD */
'25071' = 1  /* DMI CIRC NT ST UNCNTRLD */
'25072' = 1  /* DMII CIRC UNCNTRLD */
'25073' = 1  /* DMI CIRC UNCNTRLD */
'25080' = 1  /* DMII OTH NT ST UNCNTRLD */
'25081' = 1  /* DMI OTH NT ST UNCNTRLD */
'25082' = 1  /* DMII OTH UNCNTRLD */
'25083' = 1  /* DMI OTH UNCNTRLD */
'25090' = 1  /* DMII UNSPF NT ST UNCNTRL */
'25091' = 1  /* DMI UNSPF NT ST UNCNTRLD */
'25092' = 1  /* DMII UNSPF UNCNTRLD */
'25093' = 1  /* DMI UNSPF UNCNTRLD */
OTHER   = 0 ;

 /* Exclude: Trauma */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $ACLEA2D
'8950 ' = 1  /* AMPUTATION TOE */
'8951 ' = 1  /* AMPUTATION TOE-COMPLICAT */
'8960 ' = 1  /* AMPUTATION FOOT, UNILAT */
'8961 ' = 1  /* AMPUT FOOT, UNILAT-COMPL */
'8962 ' = 1  /* AMPUTATION FOOT, BILAT */
'8963 ' = 1  /* AMPUTAT FOOT, BILAT-COMP */
'8970 ' = 1  /* AMPUT BELOW KNEE, UNILAT */
'8971 ' = 1  /* AMPUTAT BK, UNILAT-COMPL */
'8972 ' = 1  /* AMPUT ABOVE KNEE, UNILAT */
'8973 ' = 1  /* AMPUT ABV KN, UNIL-COMPL */
'8974 ' = 1  /* AMPUTAT LEG, UNILAT NOS */
'8975 ' = 1  /* AMPUT LEG, UNIL NOS-COMP */
'8976 ' = 1  /* AMPUTATION LEG, BILAT */
'8977 ' = 1  /* AMPUTAT LEG, BILAT-COMPL */
OTHER   = 0 ;

 * ----------------------------------------------------- ;
 * --- DRG FORMATS  ------------------------------------ ;
 * ----------------------------------------------------- ;

 /* CMS-DRG (V24) TO MDC */;

VALUE MDCFMT
001 = 01
002 = 01
003 = 01
004 = 01
005 = 01
006 = 01
007 = 01
008 = 01
009 = 01
010 = 01
011 = 01
012 = 01
013 = 01
014 = 01
015 = 01
016 = 01
017 = 01
018 = 01
019 = 01
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 02
037 = 02
038 = 02
039 = 02
040 = 02
041 = 02
042 = 02
043 = 02
044 = 02
045 = 02
046 = 02
047 = 02
048 = 02
049 = 03
050 = 03
051 = 03
052 = 03
053 = 03
054 = 03
055 = 03
056 = 03
057 = 03
058 = 03
059 = 03
060 = 03
061 = 03
062 = 03
063 = 03
064 = 03
065 = 03
066 = 03
067 = 03
068 = 03
069 = 03
070 = 03
071 = 03
072 = 03
073 = 03
074 = 03
075 = 04
076 = 04
077 = 04
078 = 04
079 = 04
080 = 04
081 = 04
082 = 04
083 = 04
084 = 04
085 = 04
086 = 04
087 = 04
088 = 04
089 = 04
090 = 04
091 = 04
092 = 04
093 = 04
094 = 04
095 = 04
096 = 04
097 = 04
098 = 04
099 = 04
100 = 04
101 = 04
102 = 04
103 = 88
104 = 05
105 = 05
106 = 05
107 = 05
108 = 05
109 = 05
110 = 05
111 = 05
112 = 05
113 = 05
114 = 05
115 = 05
116 = 05
117 = 05
118 = 05
119 = 05
120 = 05
121 = 05
122 = 05
123 = 05
124 = 05
125 = 05
126 = 05
127 = 05
128 = 05
129 = 05
130 = 05
131 = 05
132 = 05
133 = 05
134 = 05
135 = 05
136 = 05
137 = 05
138 = 05
139 = 05
140 = 05
141 = 05
142 = 05
143 = 05
144 = 05
145 = 05
146 = 06
147 = 06
148 = 06
149 = 06
150 = 06
151 = 06
152 = 06
153 = 06
154 = 06
155 = 06
156 = 06
157 = 06
158 = 06
159 = 06
160 = 06
161 = 06
162 = 06
163 = 06
164 = 06
165 = 06
166 = 06
167 = 06
168 = 03
169 = 03
170 = 06
171 = 06
172 = 06
173 = 06
174 = 06
175 = 06
176 = 06
177 = 06
178 = 06
179 = 06
180 = 06
181 = 06
182 = 06
183 = 06
184 = 06
185 = 03
186 = 03
187 = 03
188 = 06
189 = 06
190 = 06
191 = 07
192 = 07
193 = 07
194 = 07
195 = 07
196 = 07
197 = 07
198 = 07
199 = 07
200 = 07
201 = 07
202 = 07
203 = 07
204 = 07
205 = 07
206 = 07
207 = 07
208 = 07
209 = 08
210 = 08
211 = 08
212 = 08
213 = 08
214 = 08
215 = 08
216 = 08
217 = 08
218 = 08
219 = 08
220 = 08
221 = 08
222 = 08
223 = 08
224 = 08
225 = 08
226 = 08
227 = 08
228 = 08
229 = 08
230 = 08
231 = 08
232 = 08
233 = 08
234 = 08
235 = 08
236 = 08
237 = 08
238 = 08
239 = 08
240 = 08
241 = 08
242 = 08
243 = 08
244 = 08
245 = 08
246 = 08
247 = 08
248 = 08
249 = 08
250 = 08
251 = 08
252 = 08
253 = 08
254 = 08
255 = 08
256 = 08
257 = 09
258 = 09
259 = 09
260 = 09
261 = 09
262 = 09
263 = 09
264 = 09
265 = 09
266 = 09
267 = 09
268 = 09
269 = 09
270 = 09
271 = 09
272 = 09
273 = 09
274 = 09
275 = 09
276 = 09
277 = 09
278 = 09
279 = 09
280 = 09
281 = 09
282 = 09
283 = 09
284 = 09
285 = 10
286 = 10
287 = 10
288 = 10
289 = 10
290 = 10
291 = 10
292 = 10
293 = 10
294 = 10
295 = 10
296 = 10
297 = 10
298 = 10
299 = 10
300 = 10
301 = 10
302 = 11
303 = 11
304 = 11
305 = 11
306 = 11
307 = 11
308 = 11
309 = 11
310 = 11
311 = 11
312 = 11
313 = 11
314 = 11
315 = 11
316 = 11
317 = 11
318 = 11
319 = 11
320 = 11
321 = 11
322 = 11
323 = 11
324 = 11
325 = 11
326 = 11
327 = 11
328 = 11
329 = 11
330 = 11
331 = 11
332 = 11
333 = 11
334 = 12
335 = 12
336 = 12
337 = 12
338 = 12
339 = 12
340 = 12
341 = 12
342 = 12
343 = 12
344 = 12
345 = 12
346 = 12
347 = 12
348 = 12
349 = 12
350 = 12
351 = 12
352 = 12
353 = 13
354 = 13
355 = 13
356 = 13
357 = 13
358 = 13
359 = 13
360 = 13
361 = 13
362 = 13
363 = 13
364 = 13
365 = 13
366 = 13
367 = 13
368 = 13
369 = 13
370 = 14
371 = 14
372 = 14
373 = 14
374 = 14
375 = 14
376 = 14
377 = 14
378 = 14
379 = 14
380 = 14
381 = 14
382 = 14
383 = 14
384 = 14
385 = 15
386 = 15
387 = 15
388 = 15
389 = 15
390 = 15
391 = 15
392 = 16
393 = 16
394 = 16
395 = 16
396 = 16
397 = 16
398 = 16
399 = 16
400 = 17
401 = 17
402 = 17
403 = 17
404 = 17
405 = 17
406 = 17
407 = 17
408 = 17
409 = 17
410 = 17
411 = 17
412 = 17
413 = 17
414 = 17
415 = 18
416 = 18
417 = 18
418 = 18
419 = 18
420 = 18
421 = 18
422 = 18
423 = 18
424 = 19
425 = 19
426 = 19
427 = 19
428 = 19
429 = 19
430 = 19
431 = 19
432 = 19
433 = 20
434 = 20
435 = 20
436 = 20
437 = 20
438 = 20
439 = 21
440 = 21
441 = 21
442 = 21
443 = 21
444 = 21
445 = 21
446 = 21
447 = 21
448 = 21
449 = 21
450 = 21
451 = 21
452 = 21
453 = 21
454 = 21
455 = 21
456 = 22
457 = 22
458 = 22
459 = 22
460 = 22
461 = 23
462 = 23
463 = 23
464 = 23
465 = 23
466 = 23
467 = 23
468 = 99
469 = 99
470 = 99
471 = 08
472 = 22
473 = 17
474 = 04
475 = 04
476 = 99
477 = 99
478 = 05
479 = 05
480 = 88
481 = 88
482 = 88
483 = 88
484 = 24
485 = 24
486 = 24
487 = 24
488 = 25
489 = 25
490 = 25
491 = 08
492 = 17
493 = 07
494 = 07
495 = 88
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 22
505 = 22
506 = 22
507 = 22
508 = 22
509 = 22
510 = 22
511 = 22
512 = 88
513 = 88
514 = 05
515 = 05
516 = 05
517 = 05
518 = 05
519 = 08
520 = 08
521 = 20
522 = 20
523 = 20
524 = 01
525 = 05
526 = 05
527 = 05
528 = 01
529 = 01
530 = 01
531 = 01
532 = 01
533 = 01
534 = 01
535 = 05
536 = 05
537 = 08
538 = 08
539 = 17
540 = 17
541 = 88
542 = 88
543 = 01
544 = 08
545 = 08
546 = 08
547 = 05
548 = 05
549 = 05
550 = 05
551 = 05
552 = 05
553 = 05
554 = 05
555 = 05
556 = 05
557 = 05
558 = 05
559 = 01
560 = 01
561 = 01
562 = 01
563 = 01
564 = 01
565 = 04
566 = 04
567 = 06
568 = 06
569 = 06
570 = 06
571 = 06
572 = 06
573 = 11
574 = 16
575 = 18
576 = 18
577 = 01
578 = 18
579 = 18
OTHER  = 99 ;

 /* MS-DRG (V25) TO MDC */;

VALUE MDCF2T
001 = 88
002 = 88
003 = 88
004 = 88
005 = 88
006 = 88
007 = 88
008 = 88
009 = 88
010 = 88
011 = 88
012 = 88
013 = 88
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 99
982 = 99
983 = 99
984 = 99
985 = 99
986 = 99
987 = 99
988 = 99
989 = 99
998 = 99
999 = 99
OTHER  = 99 ;


 * ----------------------------------------------------- ;
 * --- AREA FORMATS ------------------------------------ ;
 * ---   Translates FIPS State and County Code (SSCCC)   ;
 * ---   to MSA (Metropolitan Statistical Area)          ;
 * ----------------------------------------------------- ;

/* MODIFIED FIPS */

VALUE $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069'
;

/* OMB 1999 METRO AREA */

VALUE $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;

/* OMB 2003 METRO AREA */

VALUE $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740'
;


 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR AGE STRATIFIERS                            --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

Value AGEFMT
low - 4 =  1
 5 -  9 =  2
10 - 14 =  3
15 - 17 =  4
18 - 24 =  5
25 - 29 =  6
30 - 34 =  7
35 - 39 =  8
40 - 44 =  9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;

VALUE $POVCAT
"01001" = 5
"01003" = 5
"01005" = 10
"01007" = 9
"01009" = 6
"01011" = 10
"01013" = 10
"01015" = 9
"01017" = 9
"01019" = 9
"01021" = 8
"01023" = 9
"01025" = 10
"01027" = 7
"01029" = 8
"01031" = 8
"01033" = 8
"01035" = 10
"01037" = 8
"01039" = 9
"01041" = 10
"01043" = 7
"01045" = 9
"01047" = 10
"01049" = 8
"01051" = 6
"01053" = 9
"01055" = 9
"01057" = 9
"01059" = 9
"01061" = 10
"01063" = 10
"01065" = 10
"01067" = 9
"01069" = 9
"01071" = 8
"01073" = 7
"01075" = 9
"01077" = 8
"01079" = 7
"01081" = 6
"01083" = 6
"01085" = 10
"01087" = 10
"01089" = 5
"01091" = 10
"01093" = 9
"01095" = 9
"01097" = 10
"01099" = 9
"01101" = 10
"01103" = 7
"01105" = 10
"01107" = 10
"01109" = 10
"01111" = 9
"01113" = 10
"01115" = 7
"01117" = 2
"01119" = 10
"01121" = 9
"01123" = 9
"01125" = 8
"01127" = 8
"01129" = 9
"01131" = 10
"01133" = 10
"02013" = 2
"02016" = 1
"02020" = 2
"02050" = 10
"02060" = 2
"02068" = 1
"02070" = 8
"02090" = 2
"02100" = 4
"02110" = 2
"02122" = 3
"02130" = 2
"02150" = 3
"02164" = 7
"02170" = 4
"02180" = 8
"02185" = 3
"02188" = 7
"02201" = 7
"02220" = 2
"02232" = 5
"02240" = 9
"02261" = 2
"02270" = 10
"02280" = 3
"02282" = 4
"02290" = 7
"04001" = 10
"04003" = 9
"04005" = 8
"04007" = 10
"04009" = 9
"04011" = 4
"04012" = 10
"04013" = 6
"04015" = 9
"04017" = 10
"04019" = 8
"04021" = 8
"04023" = 10
"04025" = 7
"04027" = 10
"05001" = 9
"05003" = 10
"05005" = 9
"05007" = 4
"05009" = 9
"05011" = 10
"05013" = 7
"05015" = 9
"05017" = 10
"05019" = 8
"05021" = 9
"05023" = 9
"05025" = 8
"05027" = 10
"05029" = 9
"05031" = 9
"05033" = 8
"05035" = 10
"05037" = 10
"05039" = 10
"05041" = 10
"05043" = 10
"05045" = 5
"05047" = 9
"05049" = 10
"05051" = 10
"05053" = 5
"05055" = 8
"05057" = 10
"05059" = 9
"05061" = 9
"05063" = 9
"05065" = 10
"05067" = 10
"05069" = 10
"05071" = 9
"05073" = 10
"05075" = 10
"05077" = 10
"05079" = 10
"05081" = 9
"05083" = 9
"05085" = 5
"05087" = 9
"05089" = 10
"05091" = 10
"05093" = 10
"05095" = 10
"05097" = 10
"05099" = 10
"05101" = 10
"05103" = 10
"05105" = 8
"05107" = 10
"05109" = 8
"05111" = 10
"05113" = 10
"05115" = 8
"05117" = 9
"05119" = 8
"05121" = 10
"05123" = 10
"05125" = 4
"05127" = 10
"05129" = 10
"05131" = 8
"05133" = 10
"05135" = 10
"05137" = 10
"05139" = 9
"05141" = 10
"05143" = 6
"05145" = 8
"05147" = 10
"05149" = 9
"06001" = 4
"06003" = 8
"06005" = 3
"06007" = 8
"06009" = 4
"06011" = 7
"06013" = 2
"06015" = 9
"06017" = 2
"06019" = 10
"06021" = 8
"06023" = 8
"06025" = 10
"06027" = 5
"06029" = 9
"06031" = 9
"06033" = 8
"06035" = 5
"06037" = 9
"06039" = 10
"06041" = 1
"06043" = 5
"06045" = 8
"06047" = 10
"06049" = 9
"06051" = 2
"06053" = 7
"06055" = 2
"06057" = 3
"06059" = 4
"06061" = 1
"06063" = 4
"06065" = 6
"06067" = 7
"06069" = 3
"06071" = 8
"06073" = 5
"06075" = 6
"06077" = 7
"06079" = 4
"06081" = 1
"06083" = 6
"06085" = 3
"06087" = 5
"06089" = 7
"06091" = 4
"06093" = 9
"06095" = 3
"06097" = 2
"06099" = 7
"06101" = 7
"06103" = 8
"06105" = 8
"06107" = 10
"06109" = 6
"06111" = 4
"06113" = 4
"06115" = 9
"08001" = 4
"08003" = 9
"08005" = 2
"08007" = 5
"08009" = 9
"08011" = 9
"08013" = 2
"08014" = 1
"08015" = 5
"08017" = 5
"08019" = 2
"08021" = 9
"08023" = 10
"08025" = 10
"08027" = 6
"08029" = 7
"08031" = 8
"08033" = 5
"08035" = 1
"08037" = 1
"08039" = 1
"08041" = 3
"08043" = 6
"08045" = 2
"08047" = 1
"08049" = 2
"08051" = 3
"08053" = 8
"08055" = 10
"08057" = 7
"08059" = 1
"08061" = 4
"08063" = 6
"08065" = 4
"08067" = 3
"08069" = 2
"08071" = 8
"08073" = 6
"08075" = 5
"08077" = 5
"08079" = 4
"08081" = 3
"08083" = 8
"08085" = 6
"08087" = 5
"08089" = 9
"08091" = 2
"08093" = 2
"08095" = 4
"08097" = 1
"08099" = 9
"08101" = 7
"08103" = 3
"08105" = 10
"08107" = 1
"08109" = 10
"08111" = 8
"08113" = 2
"08115" = 5
"08117" = 1
"08119" = 3
"08121" = 4
"08123" = 3
"08125" = 5
"09001" = 2
"09003" = 3
"09005" = 1
"09007" = 1
"09009" = 4
"09011" = 2
"09013" = 1
"09015" = 3
"10001" = 5
"10003" = 3
"10005" = 5
"11001" = 10
"12001" = 7
"12003" = 6
"12005" = 7
"12007" = 8
"12009" = 4
"12011" = 5
"12013" = 9
"12015" = 5
"12017" = 8
"12019" = 2
"12021" = 4
"12023" = 9
"12027" = 10
"12029" = 10
"12031" = 6
"12033" = 8
"12035" = 4
"12037" = 8
"12039" = 9
"12041" = 7
"12043" = 6
"12045" = 8
"12047" = 10
"12049" = 10
"12051" = 9
"12053" = 7
"12055" = 8
"12057" = 7
"12059" = 10
"12061" = 5
"12063" = 8
"12065" = 8
"12067" = 9
"12069" = 6
"12071" = 5
"12073" = 5
"12075" = 9
"12077" = 8
"12079" = 9
"12081" = 5
"12083" = 9
"12085" = 4
"12086" = 10
"12087" = 4
"12089" = 3
"12091" = 4
"12093" = 8
"12095" = 6
"12097" = 7
"12099" = 5
"12101" = 6
"12103" = 6
"12105" = 7
"12107" = 10
"12109" = 2
"12111" = 7
"12113" = 4
"12115" = 3
"12117" = 3
"12119" = 9
"12121" = 9
"12123" = 9
"12125" = 7
"12127" = 7
"12129" = 5
"12131" = 8
"12133" = 9
"13001" = 9
"13003" = 10
"13005" = 9
"13007" = 10
"13009" = 8
"13011" = 6
"13013" = 4
"13015" = 5
"13017" = 10
"13019" = 9
"13021" = 10
"13023" = 9
"13025" = 9
"13027" = 10
"13029" = 4
"13031" = 9
"13033" = 10
"13035" = 6
"13037" = 10
"13039" = 4
"13043" = 10
"13045" = 7
"13047" = 5
"13049" = 9
"13051" = 9
"13053" = 5
"13055" = 7
"13057" = 2
"13059" = 8
"13061" = 10
"13063" = 7
"13065" = 10
"13067" = 3
"13069" = 10
"13071" = 10
"13073" = 2
"13075" = 9
"13077" = 3
"13079" = 7
"13081" = 10
"13083" = 5
"13085" = 4
"13087" = 10
"13089" = 6
"13091" = 9
"13093" = 10
"13095" = 10
"13097" = 4
"13099" = 10
"13101" = 9
"13103" = 4
"13105" = 8
"13107" = 10
"13109" = 10
"13111" = 8
"13113" = 1
"13115" = 7
"13117" = 1
"13119" = 8
"13121" = 8
"13123" = 7
"13125" = 6
"13127" = 9
"13129" = 6
"13131" = 10
"13133" = 10
"13135" = 2
"13137" = 5
"13139" = 5
"13141" = 10
"13143" = 8
"13145" = 3
"13147" = 7
"13149" = 8
"13151" = 2
"13153" = 5
"13155" = 10
"13157" = 6
"13159" = 8
"13161" = 9
"13163" = 10
"13165" = 10
"13167" = 10
"13169" = 4
"13171" = 8
"13173" = 10
"13175" = 9
"13177" = 3
"13179" = 7
"13181" = 8
"13183" = 10
"13185" = 9
"13187" = 6
"13189" = 9
"13191" = 10
"13193" = 10
"13195" = 6
"13197" = 10
"13199" = 9
"13201" = 10
"13205" = 10
"13207" = 6
"13209" = 9
"13211" = 6
"13213" = 6
"13215" = 9
"13217" = 6
"13219" = 2
"13221" = 6
"13223" = 2
"13225" = 10
"13227" = 6
"13229" = 9
"13231" = 5
"13233" = 7
"13235" = 8
"13237" = 8
"13239" = 10
"13241" = 7
"13243" = 10
"13245" = 10
"13247" = 5
"13249" = 8
"13251" = 9
"13253" = 10
"13255" = 9
"13257" = 8
"13259" = 10
"13261" = 10
"13263" = 10
"13265" = 10
"13267" = 10
"13269" = 10
"13271" = 10
"13273" = 10
"13275" = 9
"13277" = 9
"13279" = 10
"13281" = 7
"13283" = 10
"13285" = 8
"13287" = 10
"13289" = 9
"13291" = 7
"13293" = 9
"13295" = 7
"13297" = 5
"13299" = 10
"13301" = 10
"13303" = 10
"13305" = 9
"13307" = 9
"13309" = 10
"13311" = 6
"13313" = 5
"13315" = 10
"13317" = 9
"13319" = 8
"13321" = 9
"15001" = 6
"15003" = 4
"15005" = 1
"15007" = 4
"15009" = 4
"16001" = 3
"16003" = 8
"16005" = 6
"16007" = 5
"16009" = 7
"16011" = 6
"16013" = 1
"16015" = 5
"16017" = 7
"16019" = 5
"16021" = 7
"16023" = 6
"16025" = 1
"16027" = 7
"16029" = 4
"16031" = 7
"16033" = 8
"16035" = 7
"16037" = 5
"16039" = 4
"16041" = 4
"16043" = 7
"16045" = 6
"16047" = 5
"16049" = 7
"16051" = 5
"16053" = 6
"16055" = 5
"16057" = 4
"16059" = 7
"16061" = 7
"16063" = 5
"16065" = 4
"16067" = 6
"16069" = 5
"16071" = 4
"16073" = 9
"16075" = 7
"16077" = 7
"16079" = 9
"16081" = 3
"16083" = 6
"16085" = 4
"16087" = 7
"17001" = 5
"17003" = 10
"17005" = 4
"17007" = 2
"17009" = 3
"17011" = 3
"17013" = 2
"17015" = 4
"17017" = 4
"17019" = 4
"17021" = 4
"17023" = 5
"17025" = 5
"17027" = 2
"17029" = 5
"17031" = 8
"17033" = 5
"17035" = 4
"17037" = 2
"17039" = 4
"17041" = 3
"17043" = 1
"17045" = 6
"17047" = 4
"17049" = 3
"17051" = 6
"17053" = 3
"17055" = 8
"17057" = 5
"17059" = 9
"17061" = 6
"17063" = 1
"17065" = 6
"17067" = 4
"17069" = 8
"17071" = 5
"17073" = 3
"17075" = 4
"17077" = 9
"17079" = 4
"17081" = 7
"17083" = 3
"17085" = 2
"17087" = 6
"17089" = 2
"17091" = 5
"17093" = 1
"17095" = 6
"17097" = 2
"17099" = 4
"17101" = 6
"17103" = 3
"17105" = 3
"17107" = 4
"17109" = 6
"17111" = 1
"17113" = 2
"17115" = 7
"17117" = 4
"17119" = 4
"17121" = 8
"17123" = 3
"17125" = 5
"17127" = 7
"17129" = 3
"17131" = 3
"17133" = 1
"17135" = 5
"17137" = 5
"17139" = 3
"17141" = 2
"17143" = 7
"17145" = 5
"17147" = 1
"17149" = 6
"17151" = 7
"17153" = 10
"17155" = 2
"17157" = 5
"17159" = 5
"17161" = 6
"17163" = 8
"17165" = 9
"17167" = 4
"17169" = 3
"17171" = 4
"17173" = 4
"17175" = 4
"17177" = 4
"17179" = 2
"17181" = 7
"17183" = 7
"17185" = 5
"17187" = 4
"17189" = 2
"17191" = 5
"17193" = 6
"17195" = 4
"17197" = 1
"17199" = 7
"17201" = 6
"17203" = 1
"18001" = 5
"18003" = 4
"18005" = 2
"18007" = 2
"18009" = 4
"18011" = 1
"18013" = 2
"18015" = 2
"18017" = 4
"18019" = 4
"18021" = 4
"18023" = 3
"18025" = 6
"18027" = 6
"18029" = 2
"18031" = 3
"18033" = 2
"18035" = 5
"18037" = 1
"18039" = 4
"18041" = 4
"18043" = 3
"18045" = 3
"18047" = 2
"18049" = 4
"18051" = 2
"18053" = 6
"18055" = 4
"18057" = 1
"18059" = 1
"18061" = 2
"18063" = 1
"18065" = 4
"18067" = 4
"18069" = 2
"18071" = 3
"18073" = 2
"18075" = 5
"18077" = 4
"18079" = 4
"18081" = 1
"18083" = 6
"18085" = 2
"18087" = 3
"18089" = 6
"18091" = 4
"18093" = 3
"18095" = 5
"18097" = 6
"18099" = 2
"18101" = 3
"18103" = 4
"18105" = 3
"18107" = 3
"18109" = 2
"18111" = 2
"18113" = 2
"18115" = 2
"18117" = 6
"18119" = 4
"18121" = 5
"18123" = 3
"18125" = 3
"18127" = 1
"18129" = 2
"18131" = 4
"18133" = 2
"18135" = 4
"18137" = 2
"18139" = 3
"18141" = 5
"18143" = 5
"18145" = 2
"18147" = 2
"18149" = 5
"18151" = 2
"18153" = 5
"18155" = 4
"18157" = 3
"18159" = 1
"18161" = 3
"18163" = 5
"18165" = 3
"18167" = 6
"18169" = 3
"18171" = 2
"18173" = 1
"18175" = 4
"18177" = 5
"18179" = 2
"18181" = 3
"18183" = 1
"19001" = 3
"19003" = 5
"19005" = 3
"19007" = 7
"19009" = 3
"19011" = 1
"19013" = 5
"19015" = 2
"19017" = 1
"19019" = 3
"19021" = 3
"19023" = 2
"19025" = 4
"19027" = 2
"19029" = 4
"19031" = 1
"19033" = 3
"19035" = 3
"19037" = 3
"19039" = 4
"19041" = 3
"19043" = 3
"19045" = 4
"19047" = 4
"19049" = 1
"19051" = 6
"19053" = 7
"19055" = 2
"19057" = 6
"19059" = 2
"19061" = 2
"19063" = 3
"19065" = 4
"19067" = 4
"19069" = 3
"19071" = 3
"19073" = 4
"19075" = 1
"19077" = 3
"19079" = 2
"19081" = 2
"19083" = 3
"19085" = 3
"19087" = 2
"19089" = 3
"19091" = 3
"19093" = 3
"19095" = 1
"19097" = 4
"19099" = 2
"19101" = 5
"19103" = 2
"19105" = 2
"19107" = 4
"19109" = 3
"19111" = 5
"19113" = 2
"19115" = 3
"19117" = 5
"19119" = 2
"19121" = 2
"19123" = 3
"19125" = 2
"19127" = 4
"19129" = 2
"19131" = 3
"19133" = 4
"19135" = 4
"19137" = 4
"19139" = 4
"19141" = 2
"19143" = 2
"19145" = 4
"19147" = 3
"19149" = 1
"19151" = 4
"19153" = 3
"19155" = 4
"19157" = 2
"19159" = 7
"19161" = 4
"19163" = 4
"19165" = 2
"19167" = 1
"19169" = 1
"19171" = 2
"19173" = 5
"19175" = 5
"19177" = 5
"19179" = 6
"19181" = 1
"19183" = 2
"19185" = 7
"19187" = 4
"19189" = 2
"19191" = 1
"19193" = 5
"19195" = 2
"19197" = 3
"20001" = 6
"20003" = 5
"20005" = 4
"20007" = 5
"20009" = 5
"20011" = 7
"20013" = 6
"20015" = 2
"20017" = 4
"20019" = 7
"20021" = 7
"20023" = 4
"20025" = 4
"20027" = 4
"20029" = 4
"20031" = 3
"20033" = 3
"20035" = 6
"20037" = 7
"20039" = 5
"20041" = 3
"20043" = 4
"20045" = 3
"20047" = 5
"20049" = 8
"20051" = 2
"20053" = 2
"20055" = 5
"20057" = 4
"20059" = 4
"20061" = 6
"20063" = 4
"20065" = 5
"20067" = 3
"20069" = 3
"20071" = 3
"20073" = 7
"20075" = 5
"20077" = 5
"20079" = 3
"20081" = 4
"20083" = 2
"20085" = 3
"20087" = 2
"20089" = 6
"20091" = 1
"20093" = 3
"20095" = 4
"20097" = 5
"20099" = 7
"20101" = 3
"20103" = 2
"20105" = 5
"20107" = 6
"20109" = 3
"20111" = 4
"20113" = 2
"20115" = 3
"20117" = 3
"20119" = 4
"20121" = 2
"20123" = 4
"20125" = 7
"20127" = 3
"20129" = 4
"20131" = 2
"20133" = 5
"20135" = 3
"20137" = 3
"20139" = 3
"20141" = 5
"20143" = 2
"20145" = 4
"20147" = 4
"20149" = 3
"20151" = 4
"20153" = 4
"20155" = 5
"20157" = 5
"20159" = 5
"20161" = 3
"20163" = 4
"20165" = 5
"20167" = 5
"20169" = 4
"20171" = 2
"20173" = 5
"20175" = 6
"20177" = 4
"20179" = 4
"20181" = 6
"20183" = 4
"20185" = 6
"20187" = 4
"20189" = 5
"20191" = 4
"20193" = 3
"20195" = 4
"20197" = 2
"20199" = 7
"20201" = 4
"20203" = 5
"20205" = 6
"20207" = 6
"20209" = 8
"21001" = 10
"21003" = 7
"21005" = 3
"21007" = 7
"21009" = 8
"21011" = 10
"21013" = 10
"21015" = 2
"21017" = 7
"21019" = 9
"21021" = 7
"21023" = 5
"21025" = 10
"21027" = 9
"21029" = 4
"21031" = 9
"21033" = 8
"21035" = 7
"21037" = 4
"21039" = 7
"21041" = 7
"21043" = 10
"21045" = 10
"21047" = 8
"21049" = 7
"21051" = 10
"21053" = 10
"21055" = 9
"21057" = 10
"21059" = 6
"21061" = 9
"21063" = 10
"21065" = 10
"21067" = 6
"21069" = 9
"21071" = 10
"21073" = 5
"21075" = 10
"21077" = 7
"21079" = 8
"21081" = 6
"21083" = 8
"21085" = 9
"21087" = 9
"21089" = 8
"21091" = 4
"21093" = 5
"21095" = 10
"21097" = 6
"21099" = 10
"21101" = 7
"21103" = 6
"21105" = 8
"21107" = 9
"21109" = 10
"21111" = 7
"21113" = 6
"21115" = 10
"21117" = 4
"21119" = 10
"21121" = 10
"21123" = 8
"21125" = 10
"21127" = 10
"21129" = 10
"21131" = 10
"21133" = 10
"21135" = 10
"21137" = 9
"21139" = 7
"21141" = 8
"21143" = 6
"21145" = 8
"21147" = 10
"21149" = 7
"21151" = 7
"21153" = 10
"21155" = 8
"21157" = 6
"21159" = 10
"21161" = 9
"21163" = 4
"21165" = 10
"21167" = 6
"21169" = 10
"21171" = 10
"21173" = 8
"21175" = 10
"21177" = 9
"21179" = 5
"21181" = 8
"21183" = 9
"21185" = 1
"21187" = 8
"21189" = 10
"21191" = 5
"21193" = 10
"21195" = 10
"21197" = 10
"21199" = 9
"21201" = 9
"21203" = 10
"21205" = 9
"21207" = 10
"21209" = 4
"21211" = 4
"21213" = 7
"21215" = 3
"21217" = 9
"21219" = 9
"21221" = 6
"21223" = 6
"21225" = 7
"21227" = 7
"21229" = 6
"21231" = 10
"21233" = 7
"21235" = 10
"21237" = 10
"21239" = 3
"22001" = 10
"22003" = 10
"22005" = 5
"22007" = 9
"22009" = 10
"22011" = 8
"22013" = 10
"22015" = 7
"22017" = 10
"22019" = 9
"22021" = 10
"22023" = 5
"22025" = 10
"22027" = 10
"22029" = 10
"22031" = 10
"22033" = 9
"22035" = 10
"22037" = 9
"22039" = 10
"22041" = 10
"22043" = 10
"22045" = 10
"22047" = 10
"22049" = 9
"22051" = 9
"22053" = 9
"22055" = 8
"22057" = 8
"22059" = 9
"22061" = 10
"22063" = 6
"22065" = 10
"22067" = 10
"22069" = 10
"22071" = 10
"22073" = 10
"22075" = 8
"22077" = 9
"22079" = 10
"22081" = 10
"22083" = 10
"22085" = 10
"22087" = 8
"22089" = 6
"22091" = 10
"22093" = 9
"22095" = 9
"22097" = 10
"22099" = 10
"22101" = 10
"22103" = 5
"22105" = 10
"22107" = 10
"22109" = 9
"22111" = 9
"22113" = 9
"22115" = 7
"22117" = 10
"22119" = 10
"22121" = 8
"22123" = 10
"22125" = 6
"22127" = 10
"23001" = 5
"23003" = 7
"23005" = 2
"23007" = 6
"23009" = 4
"23011" = 5
"23013" = 5
"23015" = 4
"23017" = 6
"23019" = 5
"23021" = 7
"23023" = 3
"23025" = 8
"23027" = 7
"23029" = 9
"23031" = 2
"24001" = 6
"24003" = 1
"24005" = 2
"24009" = 1
"24011" = 4
"24013" = 1
"24015" = 3
"24017" = 2
"24019" = 7
"24021" = 1
"24023" = 6
"24025" = 1
"24027" = 1
"24029" = 4
"24031" = 1
"24033" = 3
"24035" = 1
"24037" = 2
"24039" = 9
"24041" = 3
"24043" = 4
"24045" = 5
"24047" = 5
"24510" = 9
"25001" = 2
"25003" = 4
"25005" = 4
"25007" = 2
"25009" = 3
"25011" = 3
"25013" = 8
"25015" = 2
"25017" = 1
"25019" = 1
"25021" = 1
"25023" = 2
"25025" = 9
"25027" = 3
"26001" = 8
"26003" = 4
"26005" = 2
"26007" = 6
"26009" = 4
"26011" = 8
"26013" = 4
"26015" = 2
"26017" = 4
"26019" = 3
"26021" = 6
"26023" = 5
"26025" = 5
"26027" = 5
"26029" = 3
"26031" = 6
"26033" = 5
"26035" = 8
"26037" = 1
"26039" = 7
"26041" = 4
"26043" = 3
"26045" = 2
"26047" = 2
"26049" = 7
"26051" = 7
"26053" = 6
"26055" = 2
"26057" = 4
"26059" = 5
"26061" = 5
"26063" = 5
"26065" = 5
"26067" = 3
"26069" = 8
"26071" = 5
"26073" = 4
"26075" = 4
"26077" = 4
"26079" = 6
"26081" = 3
"26083" = 4
"26085" = 10
"26087" = 2
"26089" = 2
"26091" = 2
"26093" = 1
"26095" = 7
"26097" = 5
"26099" = 2
"26101" = 5
"26103" = 3
"26105" = 5
"26107" = 7
"26109" = 4
"26111" = 2
"26113" = 6
"26115" = 2
"26117" = 5
"26119" = 8
"26121" = 6
"26123" = 5
"26125" = 1
"26127" = 7
"26129" = 8
"26131" = 5
"26133" = 6
"26135" = 8
"26137" = 4
"26139" = 1
"26141" = 5
"26143" = 9
"26145" = 7
"26147" = 3
"26149" = 5
"26151" = 6
"26153" = 6
"26155" = 3
"26157" = 4
"26159" = 6
"26161" = 2
"26163" = 9
"26165" = 5
"27001" = 5
"27003" = 1
"27005" = 5
"27007" = 8
"27009" = 2
"27011" = 4
"27013" = 2
"27015" = 1
"27017" = 2
"27019" = 1
"27021" = 6
"27023" = 3
"27025" = 1
"27027" = 3
"27029" = 6
"27031" = 2
"27033" = 4
"27035" = 3
"27037" = 1
"27039" = 1
"27041" = 2
"27043" = 3
"27045" = 3
"27047" = 3
"27049" = 1
"27051" = 3
"27053" = 3
"27055" = 1
"27057" = 5
"27059" = 1
"27061" = 4
"27063" = 2
"27065" = 3
"27067" = 3
"27069" = 2
"27071" = 4
"27073" = 2
"27075" = 2
"27077" = 2
"27079" = 1
"27081" = 2
"27083" = 2
"27085" = 1
"27087" = 9
"27089" = 3
"27091" = 4
"27093" = 2
"27095" = 3
"27097" = 3
"27099" = 3
"27101" = 2
"27103" = 1
"27105" = 3
"27107" = 3
"27109" = 1
"27111" = 3
"27113" = 3
"27115" = 4
"27117" = 3
"27119" = 4
"27121" = 2
"27123" = 4
"27125" = 2
"27127" = 3
"27129" = 3
"27131" = 1
"27133" = 2
"27135" = 1
"27137" = 4
"27139" = 1
"27141" = 1
"27143" = 2
"27145" = 2
"27147" = 1
"27149" = 1
"27151" = 3
"27153" = 5
"27155" = 4
"27157" = 1
"27159" = 5
"27161" = 2
"27163" = 1
"27165" = 3
"27167" = 2
"27169" = 2
"27171" = 1
"27173" = 2
"28001" = 10
"28003" = 9
"28005" = 10
"28007" = 10
"28009" = 10
"28011" = 10
"28013" = 10
"28015" = 10
"28017" = 9
"28019" = 10
"28021" = 10
"28023" = 10
"28025" = 10
"28027" = 10
"28029" = 10
"28031" = 10
"28033" = 3
"28035" = 10
"28037" = 10
"28039" = 9
"28041" = 9
"28043" = 10
"28045" = 9
"28047" = 9
"28049" = 10
"28051" = 10
"28053" = 10
"28055" = 10
"28057" = 7
"28059" = 9
"28061" = 10
"28063" = 10
"28065" = 10
"28067" = 10
"28069" = 10
"28071" = 6
"28073" = 7
"28075" = 10
"28077" = 10
"28079" = 10
"28081" = 7
"28083" = 10
"28085" = 9
"28087" = 10
"28089" = 7
"28091" = 10
"28093" = 9
"28095" = 9
"28097" = 10
"28099" = 10
"28101" = 9
"28103" = 10
"28105" = 10
"28107" = 10
"28109" = 10
"28111" = 10
"28113" = 10
"28115" = 6
"28117" = 8
"28119" = 10
"28121" = 5
"28123" = 10
"28125" = 10
"28127" = 10
"28129" = 9
"28131" = 10
"28133" = 10
"28135" = 10
"28137" = 8
"28139" = 9
"28141" = 7
"28143" = 10
"28145" = 7
"28147" = 10
"28149" = 10
"28151" = 10
"28153" = 10
"28155" = 10
"28157" = 10
"28159" = 10
"28161" = 10
"28163" = 10
"29001" = 6
"29003" = 3
"29005" = 5
"29007" = 7
"29009" = 8
"29011" = 6
"29013" = 7
"29015" = 9
"29017" = 7
"29019" = 4
"29021" = 6
"29023" = 10
"29025" = 5
"29027" = 4
"29029" = 7
"29031" = 5
"29033" = 7
"29035" = 10
"29037" = 2
"29039" = 9
"29041" = 4
"29043" = 4
"29045" = 6
"29047" = 2
"29049" = 2
"29051" = 3
"29053" = 4
"29055" = 8
"29057" = 7
"29059" = 8
"29061" = 9
"29063" = 4
"29065" = 9
"29067" = 10
"29069" = 10
"29071" = 3
"29073" = 4
"29075" = 5
"29077" = 6
"29079" = 8
"29081" = 7
"29083" = 7
"29085" = 10
"29087" = 5
"29089" = 5
"29091" = 9
"29093" = 10
"29095" = 6
"29097" = 8
"29099" = 2
"29101" = 4
"29103" = 8
"29105" = 8
"29107" = 4
"29109" = 7
"29111" = 6
"29113" = 3
"29115" = 7
"29117" = 6
"29119" = 9
"29121" = 6
"29123" = 9
"29125" = 6
"29127" = 6
"29129" = 6
"29131" = 7
"29133" = 10
"29135" = 4
"29137" = 5
"29139" = 5
"29141" = 9
"29143" = 10
"29145" = 6
"29147" = 3
"29149" = 10
"29151" = 2
"29153" = 10
"29155" = 10
"29157" = 3
"29159" = 7
"29161" = 7
"29163" = 7
"29165" = 1
"29167" = 8
"29169" = 4
"29171" = 7
"29173" = 4
"29175" = 6
"29177" = 3
"29179" = 10
"29181" = 10
"29183" = 1
"29185" = 9
"29186" = 3
"29187" = 7
"29189" = 3
"29195" = 7
"29197" = 7
"29199" = 7
"29201" = 8
"29203" = 10
"29205" = 7
"29207" = 8
"29209" = 8
"29211" = 7
"29213" = 8
"29215" = 10
"29217" = 8
"29219" = 3
"29221" = 9
"29223" = 10
"29225" = 8
"29227" = 7
"29229" = 10
"29510" = 10
"30001" = 8
"30003" = 10
"30005" = 10
"30007" = 7
"30009" = 5
"30011" = 6
"30013" = 7
"30015" = 7
"30017" = 7
"30019" = 6
"30021" = 6
"30023" = 7
"30025" = 3
"30027" = 8
"30029" = 6
"30031" = 3
"30033" = 7
"30035" = 10
"30037" = 9
"30039" = 8
"30041" = 9
"30043" = 3
"30045" = 8
"30047" = 10
"30049" = 5
"30051" = 4
"30053" = 10
"30055" = 7
"30057" = 6
"30059" = 9
"30061" = 10
"30063" = 7
"30065" = 10
"30067" = 6
"30069" = 6
"30071" = 8
"30073" = 8
"30075" = 4
"30077" = 8
"30079" = 7
"30081" = 8
"30083" = 6
"30085" = 10
"30087" = 9
"30089" = 10
"30091" = 6
"30093" = 8
"30095" = 3
"30097" = 4
"30099" = 6
"30101" = 5
"30103" = 7
"30105" = 8
"30107" = 10
"30109" = 6
"30111" = 5
"31001" = 3
"31003" = 5
"31005" = 4
"31007" = 3
"31009" = 9
"31011" = 3
"31013" = 5
"31015" = 5
"31017" = 6
"31019" = 3
"31021" = 4
"31023" = 3
"31025" = 2
"31027" = 2
"31029" = 4
"31031" = 6
"31033" = 3
"31035" = 4
"31037" = 3
"31039" = 3
"31041" = 6
"31043" = 4
"31045" = 7
"31047" = 4
"31049" = 5
"31051" = 3
"31053" = 3
"31055" = 4
"31057" = 5
"31059" = 4
"31061" = 5
"31063" = 4
"31065" = 5
"31067" = 3
"31069" = 7
"31071" = 4
"31073" = 3
"31075" = 5
"31077" = 6
"31079" = 5
"31081" = 2
"31083" = 5
"31085" = 4
"31087" = 7
"31089" = 5
"31091" = 4
"31093" = 4
"31095" = 4
"31097" = 3
"31099" = 2
"31101" = 4
"31103" = 7
"31105" = 7
"31107" = 7
"31109" = 3
"31111" = 5
"31113" = 4
"31115" = 6
"31117" = 7
"31119" = 4
"31121" = 4
"31123" = 7
"31125" = 5
"31127" = 3
"31129" = 5
"31131" = 2
"31133" = 5
"31135" = 4
"31137" = 3
"31139" = 3
"31141" = 2
"31143" = 2
"31145" = 4
"31147" = 5
"31149" = 8
"31151" = 2
"31153" = 1
"31155" = 2
"31157" = 8
"31159" = 1
"31161" = 8
"31163" = 5
"31165" = 4
"31167" = 2
"31169" = 4
"31171" = 5
"31173" = 10
"31175" = 5
"31177" = 1
"31179" = 3
"31181" = 3
"31183" = 7
"31185" = 3
"32001" = 4
"32003" = 5
"32005" = 2
"32007" = 3
"32009" = 4
"32011" = 3
"32013" = 4
"32015" = 3
"32017" = 7
"32019" = 4
"32021" = 8
"32023" = 7
"32027" = 5
"32029" = 1
"32031" = 3
"32033" = 5
"32510" = 4
"33001" = 2
"33003" = 2
"33005" = 2
"33007" = 4
"33009" = 2
"33011" = 1
"33013" = 1
"33015" = 1
"33017" = 2
"33019" = 2
"34001" = 4
"34003" = 1
"34005" = 1
"34007" = 4
"34009" = 4
"34011" = 7
"34013" = 7
"34015" = 1
"34017" = 8
"34019" = 1
"34021" = 2
"34023" = 2
"34025" = 1
"34027" = 1
"34029" = 3
"34031" = 6
"34033" = 3
"34035" = 1
"34037" = 1
"34039" = 3
"34041" = 1
"35001" = 7
"35003" = 10
"35005" = 10
"35006" = 10
"35007" = 9
"35009" = 10
"35011" = 10
"35013" = 10
"35015" = 9
"35017" = 10
"35019" = 10
"35021" = 6
"35023" = 10
"35025" = 9
"35027" = 10
"35028" = 1
"35029" = 10
"35031" = 10
"35033" = 10
"35035" = 9
"35037" = 10
"35039" = 9
"35041" = 10
"35043" = 5
"35045" = 10
"35047" = 10
"35049" = 6
"35051" = 10
"35053" = 10
"35055" = 10
"35057" = 10
"35059" = 9
"35061" = 9
"36001" = 4
"36003" = 7
"36005" = 10
"36007" = 6
"36009" = 7
"36011" = 5
"36013" = 8
"36015" = 7
"36017" = 7
"36019" = 5
"36021" = 4
"36023" = 6
"36025" = 7
"36027" = 2
"36029" = 6
"36031" = 5
"36033" = 7
"36035" = 7
"36037" = 3
"36039" = 6
"36041" = 4
"36043" = 6
"36045" = 7
"36047" = 10
"36049" = 6
"36051" = 4
"36053" = 4
"36055" = 6
"36057" = 7
"36059" = 1
"36061" = 10
"36063" = 5
"36065" = 6
"36067" = 5
"36069" = 3
"36071" = 4
"36073" = 6
"36075" = 6
"36077" = 5
"36079" = 1
"36081" = 8
"36083" = 4
"36085" = 4
"36087" = 4
"36089" = 7
"36091" = 1
"36093" = 5
"36095" = 5
"36097" = 6
"36099" = 5
"36101" = 7
"36103" = 2
"36105" = 7
"36107" = 4
"36109" = 4
"36111" = 4
"36113" = 4
"36115" = 5
"36117" = 4
"36119" = 3
"36121" = 4
"36123" = 7
"37001" = 5
"37003" = 5
"37005" = 9
"37007" = 9
"37009" = 8
"37011" = 7
"37013" = 9
"37015" = 10
"37017" = 10
"37019" = 8
"37021" = 7
"37023" = 7
"37025" = 4
"37027" = 7
"37029" = 3
"37031" = 6
"37033" = 7
"37035" = 6
"37037" = 4
"37039" = 9
"37041" = 9
"37043" = 8
"37045" = 8
"37047" = 10
"37049" = 7
"37051" = 8
"37053" = 4
"37055" = 3
"37057" = 6
"37059" = 3
"37061" = 9
"37063" = 7
"37065" = 10
"37067" = 6
"37069" = 6
"37071" = 7
"37073" = 6
"37075" = 9
"37077" = 5
"37079" = 9
"37081" = 7
"37083" = 10
"37085" = 8
"37087" = 8
"37089" = 6
"37091" = 10
"37093" = 8
"37095" = 10
"37097" = 4
"37099" = 7
"37101" = 6
"37103" = 8
"37105" = 7
"37107" = 9
"37109" = 5
"37111" = 6
"37113" = 7
"37115" = 8
"37117" = 10
"37119" = 5
"37121" = 8
"37123" = 8
"37125" = 6
"37127" = 7
"37129" = 7
"37131" = 10
"37133" = 7
"37135" = 3
"37137" = 9
"37139" = 9
"37141" = 8
"37143" = 9
"37145" = 5
"37147" = 8
"37149" = 5
"37151" = 5
"37153" = 9
"37155" = 10
"37157" = 6
"37159" = 5
"37161" = 8
"37163" = 9
"37165" = 10
"37167" = 5
"37169" = 4
"37171" = 7
"37173" = 8
"37175" = 7
"37177" = 10
"37179" = 3
"37181" = 10
"37183" = 2
"37185" = 10
"37187" = 10
"37189" = 5
"37191" = 8
"37193" = 7
"37195" = 8
"37197" = 5
"37199" = 9
"38001" = 4
"38003" = 4
"38005" = 10
"38007" = 6
"38009" = 5
"38011" = 3
"38013" = 4
"38015" = 2
"38017" = 2
"38019" = 4
"38021" = 6
"38023" = 4
"38025" = 5
"38027" = 3
"38029" = 6
"38031" = 2
"38033" = 6
"38035" = 4
"38037" = 9
"38039" = 4
"38041" = 4
"38043" = 6
"38045" = 4
"38047" = 6
"38049" = 7
"38051" = 6
"38053" = 7
"38055" = 6
"38057" = 2
"38059" = 3
"38061" = 7
"38063" = 4
"38065" = 3
"38067" = 3
"38069" = 5
"38071" = 6
"38073" = 2
"38075" = 4
"38077" = 2
"38079" = 10
"38081" = 2
"38083" = 9
"38085" = 10
"38087" = 5
"38089" = 4
"38091" = 2
"38093" = 4
"38095" = 4
"38097" = 2
"38099" = 4
"38101" = 4
"38103" = 4
"38105" = 5
"39001" = 8
"39003" = 5
"39005" = 3
"39007" = 6
"39009" = 8
"39011" = 1
"39013" = 7
"39015" = 4
"39017" = 2
"39019" = 5
"39021" = 3
"39023" = 6
"39025" = 2
"39027" = 3
"39029" = 6
"39031" = 4
"39033" = 5
"39035" = 7
"39037" = 2
"39039" = 2
"39041" = 1
"39043" = 4
"39045" = 2
"39047" = 5
"39049" = 5
"39051" = 2
"39053" = 9
"39055" = 1
"39057" = 2
"39059" = 7
"39061" = 5
"39063" = 2
"39065" = 4
"39067" = 6
"39069" = 2
"39071" = 5
"39073" = 5
"39075" = 4
"39077" = 3
"39079" = 8
"39081" = 7
"39083" = 4
"39085" = 2
"39087" = 9
"39089" = 3
"39091" = 3
"39093" = 4
"39095" = 6
"39097" = 3
"39099" = 7
"39101" = 5
"39103" = 1
"39105" = 9
"39107" = 2
"39109" = 2
"39111" = 7
"39113" = 5
"39115" = 8
"39117" = 4
"39119" = 7
"39121" = 5
"39123" = 2
"39125" = 3
"39127" = 6
"39129" = 4
"39131" = 9
"39133" = 2
"39135" = 2
"39137" = 1
"39139" = 5
"39141" = 6
"39143" = 2
"39145" = 9
"39147" = 3
"39149" = 2
"39151" = 4
"39153" = 5
"39155" = 5
"39157" = 4
"39159" = 1
"39161" = 2
"39163" = 8
"39165" = 1
"39167" = 5
"39169" = 3
"39171" = 2
"39173" = 1
"39175" = 1
"40001" = 10
"40003" = 6
"40005" = 10
"40007" = 5
"40009" = 8
"40011" = 9
"40013" = 9
"40015" = 10
"40017" = 3
"40019" = 8
"40021" = 10
"40023" = 10
"40025" = 7
"40027" = 4
"40029" = 10
"40031" = 8
"40033" = 7
"40035" = 8
"40037" = 7
"40039" = 8
"40041" = 10
"40043" = 7
"40045" = 6
"40047" = 7
"40049" = 9
"40051" = 7
"40053" = 6
"40055" = 10
"40057" = 10
"40059" = 5
"40061" = 10
"40063" = 10
"40065" = 7
"40067" = 9
"40069" = 9
"40071" = 9
"40073" = 4
"40075" = 10
"40077" = 10
"40079" = 10
"40081" = 7
"40083" = 6
"40085" = 7
"40087" = 5
"40089" = 10
"40091" = 10
"40093" = 5
"40095" = 8
"40097" = 9
"40099" = 8
"40101" = 9
"40103" = 6
"40105" = 8
"40107" = 10
"40109" = 8
"40111" = 10
"40113" = 7
"40115" = 9
"40117" = 7
"40119" = 7
"40121" = 9
"40123" = 9
"40125" = 9
"40127" = 10
"40129" = 6
"40131" = 4
"40133" = 10
"40135" = 10
"40137" = 8
"40139" = 5
"40141" = 10
"40143" = 6
"40145" = 5
"40147" = 6
"40149" = 8
"40151" = 7
"40153" = 6
"41001" = 7
"41003" = 3
"41005" = 3
"41007" = 6
"41009" = 3
"41011" = 9
"41013" = 6
"41015" = 7
"41017" = 4
"41019" = 7
"41021" = 3
"41023" = 6
"41025" = 7
"41027" = 6
"41029" = 7
"41031" = 8
"41033" = 9
"41035" = 8
"41037" = 8
"41039" = 7
"41041" = 8
"41043" = 6
"41045" = 9
"41047" = 7
"41049" = 6
"41051" = 6
"41053" = 4
"41055" = 6
"41057" = 6
"41059" = 7
"41061" = 5
"41063" = 5
"41065" = 7
"41067" = 2
"41069" = 7
"41071" = 4
"42001" = 2
"42003" = 4
"42005" = 5
"42007" = 4
"42009" = 5
"42011" = 4
"42013" = 6
"42015" = 5
"42017" = 1
"42019" = 2
"42021" = 5
"42023" = 5
"42025" = 4
"42027" = 3
"42029" = 1
"42031" = 5
"42033" = 7
"42035" = 6
"42037" = 4
"42039" = 7
"42041" = 1
"42043" = 3
"42045" = 3
"42047" = 3
"42049" = 6
"42051" = 9
"42053" = 7
"42055" = 3
"42057" = 4
"42059" = 8
"42061" = 5
"42063" = 7
"42065" = 6
"42067" = 3
"42069" = 4
"42071" = 3
"42073" = 6
"42075" = 3
"42077" = 4
"42079" = 5
"42081" = 5
"42083" = 6
"42085" = 7
"42087" = 7
"42089" = 3
"42091" = 1
"42093" = 3
"42095" = 2
"42097" = 4
"42099" = 3
"42101" = 10
"42103" = 2
"42105" = 6
"42107" = 4
"42109" = 3
"42111" = 6
"42113" = 5
"42115" = 5
"42117" = 6
"42119" = 3
"42121" = 7
"42123" = 5
"42125" = 3
"42127" = 5
"42129" = 3
"42131" = 4
"42133" = 2
"44001" = 1
"44003" = 2
"44005" = 2
"44007" = 8
"44009" = 1
"45001" = 6
"45003" = 7
"45005" = 10
"45007" = 5
"45009" = 10
"45011" = 9
"45013" = 6
"45015" = 5
"45017" = 7
"45019" = 7
"45021" = 8
"45023" = 8
"45025" = 9
"45027" = 10
"45029" = 10
"45031" = 10
"45033" = 10
"45035" = 5
"45037" = 7
"45039" = 8
"45041" = 9
"45043" = 9
"45045" = 5
"45047" = 7
"45049" = 10
"45051" = 8
"45053" = 10
"45055" = 6
"45057" = 7
"45059" = 8
"45061" = 10
"45063" = 5
"45065" = 8
"45067" = 10
"45069" = 10
"45071" = 8
"45073" = 6
"45075" = 10
"45077" = 5
"45079" = 6
"45081" = 7
"45083" = 6
"45085" = 9
"45087" = 8
"45089" = 10
"45091" = 5
"46003" = 6
"46005" = 5
"46007" = 10
"46009" = 5
"46011" = 2
"46013" = 3
"46015" = 5
"46017" = 10
"46019" = 7
"46021" = 3
"46023" = 10
"46025" = 6
"46027" = 6
"46029" = 4
"46031" = 10
"46033" = 5
"46035" = 4
"46037" = 7
"46039" = 3
"46041" = 10
"46043" = 5
"46045" = 4
"46047" = 8
"46049" = 4
"46051" = 3
"46053" = 9
"46055" = 5
"46057" = 4
"46059" = 3
"46061" = 3
"46063" = 5
"46065" = 4
"46067" = 4
"46069" = 4
"46071" = 10
"46073" = 4
"46075" = 6
"46077" = 3
"46079" = 3
"46081" = 4
"46083" = 1
"46085" = 9
"46087" = 3
"46089" = 5
"46091" = 4
"46093" = 4
"46095" = 10
"46097" = 4
"46099" = 3
"46101" = 3
"46103" = 6
"46105" = 6
"46107" = 4
"46109" = 9
"46111" = 5
"46113" = 10
"46115" = 5
"46117" = 3
"46119" = 2
"46121" = 10
"46123" = 9
"46125" = 2
"46127" = 1
"46129" = 9
"46135" = 4
"46137" = 10
"47001" = 7
"47003" = 6
"47005" = 9
"47007" = 9
"47009" = 5
"47011" = 6
"47013" = 10
"47015" = 6
"47017" = 8
"47019" = 9
"47021" = 3
"47023" = 7
"47025" = 10
"47027" = 10
"47029" = 10
"47031" = 7
"47033" = 7
"47035" = 9
"47037" = 7
"47039" = 8
"47041" = 7
"47043" = 5
"47045" = 8
"47047" = 5
"47049" = 10
"47051" = 6
"47053" = 7
"47055" = 7
"47057" = 8
"47059" = 7
"47061" = 10
"47063" = 7
"47065" = 7
"47067" = 10
"47069" = 9
"47071" = 10
"47073" = 8
"47075" = 9
"47077" = 7
"47079" = 8
"47081" = 8
"47083" = 7
"47085" = 6
"47087" = 9
"47089" = 7
"47091" = 10
"47093" = 6
"47095" = 10
"47097" = 8
"47099" = 7
"47101" = 9
"47103" = 6
"47105" = 5
"47107" = 7
"47109" = 9
"47111" = 8
"47113" = 7
"47115" = 7
"47117" = 5
"47119" = 5
"47121" = 9
"47123" = 8
"47125" = 5
"47127" = 4
"47129" = 9
"47131" = 7
"47133" = 9
"47135" = 7
"47137" = 9
"47139" = 8
"47141" = 7
"47143" = 8
"47145" = 7
"47147" = 4
"47149" = 3
"47151" = 10
"47153" = 8
"47155" = 7
"47157" = 8
"47159" = 5
"47161" = 7
"47163" = 7
"47165" = 4
"47167" = 6
"47169" = 7
"47171" = 7
"47173" = 9
"47175" = 8
"47177" = 8
"47179" = 6
"47181" = 9
"47183" = 7
"47185" = 8
"47187" = 1
"47189" = 2
"48001" = 9
"48003" = 7
"48005" = 9
"48007" = 10
"48009" = 2
"48011" = 4
"48013" = 10
"48015" = 4
"48017" = 10
"48019" = 7
"48021" = 6
"48023" = 9
"48025" = 10
"48027" = 7
"48029" = 9
"48031" = 4
"48033" = 3
"48035" = 8
"48037" = 9
"48039" = 4
"48041" = 7
"48043" = 9
"48045" = 9
"48047" = 10
"48049" = 10
"48051" = 8
"48053" = 7
"48055" = 7
"48057" = 8
"48059" = 8
"48061" = 10
"48063" = 10
"48065" = 3
"48067" = 9
"48069" = 10
"48071" = 4
"48073" = 9
"48075" = 10
"48077" = 5
"48079" = 10
"48081" = 8
"48083" = 10
"48085" = 1
"48087" = 10
"48089" = 8
"48091" = 4
"48093" = 10
"48095" = 9
"48097" = 7
"48099" = 6
"48101" = 10
"48103" = 5
"48105" = 7
"48107" = 10
"48109" = 10
"48111" = 7
"48113" = 8
"48115" = 10
"48117" = 9
"48119" = 9
"48121" = 2
"48123" = 9
"48125" = 9
"48127" = 10
"48129" = 9
"48131" = 10
"48133" = 10
"48135" = 10
"48137" = 10
"48139" = 4
"48141" = 10
"48143" = 7
"48145" = 10
"48147" = 7
"48149" = 6
"48151" = 8
"48153" = 10
"48155" = 8
"48157" = 2
"48159" = 8
"48161" = 8
"48163" = 10
"48165" = 10
"48167" = 6
"48169" = 9
"48171" = 5
"48173" = 6
"48175" = 8
"48177" = 10
"48179" = 7
"48181" = 7
"48183" = 9
"48185" = 8
"48187" = 6
"48189" = 10
"48191" = 10
"48193" = 9
"48195" = 6
"48197" = 9
"48199" = 5
"48201" = 8
"48203" = 8
"48205" = 2
"48207" = 10
"48209" = 4
"48211" = 3
"48213" = 9
"48215" = 10
"48217" = 9
"48219" = 9
"48221" = 6
"48223" = 8
"48225" = 10
"48227" = 10
"48229" = 10
"48231" = 8
"48233" = 6
"48235" = 5
"48237" = 6
"48239" = 7
"48241" = 9
"48243" = 9
"48245" = 9
"48247" = 10
"48249" = 10
"48251" = 5
"48253" = 10
"48255" = 10
"48257" = 5
"48259" = 3
"48261" = 7
"48263" = 3
"48265" = 8
"48267" = 10
"48269" = 7
"48271" = 10
"48273" = 10
"48275" = 10
"48277" = 10
"48279" = 10
"48281" = 7
"48283" = 10
"48285" = 7
"48287" = 5
"48289" = 8
"48291" = 8
"48293" = 9
"48295" = 7
"48297" = 8
"48299" = 8
"48301" = 2
"48303" = 9
"48305" = 10
"48307" = 10
"48309" = 9
"48311" = 4
"48313" = 9
"48315" = 10
"48317" = 9
"48319" = 8
"48321" = 9
"48323" = 10
"48325" = 8
"48327" = 10
"48329" = 8
"48331" = 9
"48333" = 9
"48335" = 9
"48337" = 8
"48339" = 4
"48341" = 6
"48343" = 9
"48345" = 8
"48347" = 9
"48349" = 9
"48351" = 10
"48353" = 10
"48355" = 10
"48357" = 5
"48359" = 6
"48361" = 8
"48363" = 9
"48365" = 7
"48367" = 5
"48369" = 7
"48371" = 10
"48373" = 10
"48375" = 10
"48377" = 10
"48379" = 8
"48381" = 2
"48383" = 6
"48385" = 10
"48387" = 10
"48389" = 10
"48391" = 8
"48393" = 2
"48395" = 10
"48397" = 2
"48399" = 9
"48401" = 7
"48403" = 10
"48405" = 10
"48407" = 9
"48409" = 9
"48411" = 10
"48413" = 8
"48415" = 9
"48417" = 6
"48419" = 9
"48421" = 5
"48423" = 7
"48425" = 4
"48427" = 10
"48429" = 10
"48431" = 5
"48433" = 8
"48435" = 6
"48437" = 10
"48439" = 6
"48441" = 8
"48443" = 9
"48445" = 10
"48447" = 6
"48449" = 8
"48451" = 9
"48453" = 6
"48455" = 10
"48457" = 9
"48459" = 9
"48461" = 8
"48463" = 10
"48465" = 10
"48467" = 7
"48469" = 8
"48471" = 8
"48473" = 8
"48475" = 9
"48477" = 6
"48479" = 10
"48481" = 7
"48483" = 8
"48485" = 7
"48487" = 9
"48489" = 10
"48491" = 2
"48493" = 5
"48495" = 8
"48497" = 4
"48499" = 9
"48501" = 7
"48503" = 9
"48505" = 10
"48507" = 10
"49001" = 3
"49003" = 2
"49005" = 2
"49007" = 5
"49009" = 1
"49011" = 2
"49013" = 6
"49015" = 4
"49017" = 4
"49019" = 7
"49021" = 6
"49023" = 3
"49025" = 3
"49027" = 4
"49029" = 1
"49031" = 6
"49033" = 2
"49035" = 3
"49037" = 9
"49039" = 5
"49041" = 5
"49043" = 1
"49045" = 2
"49047" = 5
"49049" = 3
"49051" = 2
"49053" = 5
"49055" = 5
"49057" = 3
"50001" = 2
"50003" = 4
"50005" = 6
"50007" = 1
"50009" = 7
"50011" = 3
"50013" = 2
"50015" = 3
"50017" = 3
"50019" = 7
"50021" = 4
"50023" = 2
"50025" = 4
"50027" = 3
"51001" = 9
"51003" = 2
"51005" = 5
"51007" = 4
"51009" = 5
"51011" = 6
"51013" = 2
"51015" = 2
"51017" = 2
"51019" = 2
"51021" = 5
"51023" = 1
"51025" = 9
"51027" = 10
"51029" = 8
"51031" = 5
"51033" = 5
"51035" = 8
"51036" = 5
"51037" = 9
"51041" = 2
"51043" = 1
"51045" = 4
"51047" = 3
"51049" = 8
"51051" = 9
"51053" = 4
"51057" = 7
"51059" = 1
"51061" = 1
"51063" = 5
"51065" = 2
"51067" = 6
"51069" = 2
"51071" = 5
"51073" = 3
"51075" = 2
"51077" = 9
"51079" = 2
"51081" = 6
"51083" = 9
"51085" = 1
"51087" = 2
"51089" = 7
"51091" = 5
"51093" = 4
"51095" = 2
"51097" = 5
"51099" = 2
"51101" = 2
"51103" = 8
"51105" = 10
"51107" = 1
"51109" = 4
"51111" = 8
"51113" = 4
"51115" = 4
"51117" = 8
"51119" = 7
"51121" = 4
"51125" = 5
"51127" = 2
"51131" = 10
"51133" = 8
"51135" = 8
"51137" = 3
"51139" = 5
"51141" = 7
"51143" = 6
"51145" = 1
"51147" = 8
"51149" = 2
"51153" = 1
"51155" = 7
"51157" = 2
"51159" = 7
"51161" = 2
"51163" = 4
"51165" = 3
"51167" = 9
"51169" = 7
"51171" = 3
"51173" = 8
"51175" = 7
"51177" = 1
"51179" = 1
"51181" = 5
"51183" = 8
"51185" = 9
"51187" = 3
"51191" = 6
"51193" = 8
"51195" = 10
"51197" = 7
"51199" = 1
"51510" = 4
"51515" = 8
"51520" = 10
"51530" = 5
"51540" = 8
"51550" = 3
"51570" = 2
"51580" = 7
"51590" = 10
"51595" = 9
"51600" = 1
"51610" = 1
"51620" = 10
"51630" = 7
"51640" = 10
"51650" = 6
"51660" = 7
"51670" = 9
"51678" = 4
"51680" = 9
"51683" = 2
"51685" = 2
"51690" = 9
"51700" = 7
"51710" = 10
"51720" = 10
"51730" = 10
"51735" = 1
"51740" = 9
"51750" = 5
"51760" = 10
"51770" = 10
"51775" = 3
"51790" = 7
"51800" = 5
"51810" = 2
"51820" = 7
"51830" = 7
"51840" = 6
"53001" = 8
"53003" = 8
"53005" = 4
"53007" = 6
"53009" = 6
"53011" = 4
"53013" = 7
"53015" = 6
"53017" = 5
"53019" = 9
"53021" = 8
"53023" = 5
"53025" = 8
"53027" = 8
"53029" = 2
"53031" = 6
"53033" = 3
"53035" = 3
"53037" = 4
"53039" = 7
"53041" = 7
"53043" = 5
"53045" = 6
"53047" = 10
"53049" = 8
"53051" = 9
"53053" = 4
"53055" = 4
"53057" = 5
"53059" = 5
"53061" = 3
"53063" = 6
"53065" = 8
"53067" = 3
"53069" = 4
"53071" = 7
"53073" = 5
"53075" = 4
"53077" = 9
"54001" = 10
"54003" = 6
"54005" = 10
"54007" = 10
"54009" = 5
"54011" = 9
"54013" = 10
"54015" = 10
"54017" = 10
"54019" = 10
"54021" = 10
"54023" = 8
"54025" = 9
"54027" = 8
"54029" = 5
"54031" = 7
"54033" = 9
"54035" = 8
"54037" = 3
"54039" = 9
"54041" = 10
"54043" = 10
"54045" = 10
"54047" = 10
"54049" = 9
"54051" = 8
"54053" = 9
"54055" = 10
"54057" = 8
"54059" = 10
"54061" = 6
"54063" = 8
"54065" = 5
"54067" = 10
"54069" = 7
"54071" = 7
"54073" = 5
"54075" = 9
"54077" = 9
"54079" = 4
"54081" = 10
"54083" = 9
"54085" = 9
"54087" = 10
"54089" = 10
"54091" = 9
"54093" = 8
"54095" = 9
"54097" = 10
"54099" = 10
"54101" = 10
"54103" = 9
"54105" = 10
"54107" = 8
"54109" = 10
"55001" = 6
"55003" = 6
"55005" = 3
"55007" = 4
"55009" = 2
"55011" = 2
"55013" = 5
"55015" = 1
"55017" = 3
"55019" = 5
"55021" = 1
"55023" = 4
"55025" = 2
"55027" = 1
"55029" = 2
"55031" = 5
"55033" = 3
"55035" = 2
"55037" = 2
"55039" = 1
"55041" = 4
"55043" = 3
"55045" = 2
"55047" = 3
"55049" = 2
"55051" = 4
"55053" = 3
"55055" = 1
"55057" = 4
"55059" = 3
"55061" = 1
"55063" = 2
"55065" = 3
"55067" = 4
"55069" = 2
"55071" = 2
"55073" = 2
"55075" = 3
"55077" = 3
"55078" = 10
"55079" = 9
"55081" = 4
"55083" = 2
"55085" = 2
"55087" = 1
"55089" = 1
"55091" = 3
"55093" = 1
"55095" = 2
"55097" = 2
"55099" = 3
"55101" = 3
"55103" = 4
"55105" = 3
"55107" = 5
"55109" = 1
"55111" = 2
"55113" = 6
"55115" = 3
"55117" = 1
"55119" = 3
"55121" = 2
"55123" = 5
"55125" = 3
"55127" = 2
"55129" = 4
"55131" = 1
"55133" = 1
"55135" = 2
"55137" = 4
"55139" = 1
"55141" = 2
"56001" = 5
"56003" = 7
"56005" = 2
"56007" = 5
"56009" = 4
"56011" = 2
"56013" = 7
"56015" = 7
"56017" = 5
"56019" = 4
"56021" = 4
"56023" = 3
"56025" = 6
"56027" = 7
"56029" = 5
"56031" = 5
"56033" = 5
"56035" = 2
"56037" = 3
"56039" = 1
"56041" = 4
"56043" = 5
"56045" = 3
OTHER = 0
;

RUN;

